package com.caimei.aop;


import com.alibaba.fastjson.JSONObject;
import com.caimei.model.dto.MessageDto;
import com.caimei.service.aopservice.RocketMqService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Method;


/**
 *
 */
@Slf4j
@Aspect
@Component
public class IpSaveAspect {

    @Autowired
    private RocketMqService rocketMqService;
    /**
     * 切入点,根据自定义IpSave实际路径进行调整
     */
    @Pointcut("@annotation(com.caimei.aop.IpSave)")
    public void executeIdempotent() {
    }

    @Around("executeIdempotent()")
    public Object around(ProceedingJoinPoint joinPoint) throws Throwable {
        //获取方法对象
        Method method = ((MethodSignature) joinPoint.getSignature()).getMethod();
        RequestAttributes requestAttributes = RequestContextHolder.getRequestAttributes();
        ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes) requestAttributes;
        HttpServletRequest request = servletRequestAttributes.getRequest();
        // ip
        String unknown = "unknown";
        String ip = "";
        ip = request.getHeader("x-forwarded-for");
        if (StringUtils.isBlank(ip)) {
            ip = request.getHeader("X-Real-IP");
        }
        if (ip == null || ip.length() == 0 || unknown.equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }

        if (ip == null || ip.length() == 0 || unknown.equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }

        if (ip == null || ip.length() == 0 || unknown.equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        // 接口路径
        String requestURI = request.getRequestURI();
        //获取自定义注解
        IpSave ipSave = method.getAnnotation(IpSave.class);
        // 访问名 注解的值
        String s = ipSave.saveName();
        // 是否存储发送参数
        boolean sp = ipSave.saveParams();
        // 接口真实发送参数
        String queryString = "";
        JSONObject jsonObject = new JSONObject();
        if (sp) {
            queryString = request.getQueryString();
            jsonObject.put("queryString",queryString);
        }
        if (StringUtils.isNotBlank(ip)) {
            jsonObject.put("ip",ip);
        }
        if (StringUtils.isNotBlank(requestURI)) {
            jsonObject.put("URI",requestURI);
        }
        if (StringUtils.isNotBlank(s)) {
            jsonObject.put("saveName",s);
        }
        MessageDto messageDto = new MessageDto();
        messageDto.setTopic("zpIp");
        messageDto.setContent(jsonObject.toJSONString());
        messageDto.setSort(1);
        messageDto.setAsync(1);
        //异步给mq存
        rocketMqService.sendCommonMessage(messageDto);

        return joinPoint.proceed();
    }
}

