package com.caimei.config;

import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.jdbc.DataSourceBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

/**
 * @author Aslee
 */
@Configuration
@MapperScan(basePackages = "com.caimei.mapper.cmMapper,com.caimei.module", sqlSessionTemplateRef = "cmSqlSessionTemplate")
public class CmDataSourceConfig {

    @Bean(name = "cmDataSource")
    @ConfigurationProperties(prefix = "spring.datasource.cmdatasource")
    @Primary
    public DataSource cmDataSource() {
        return DataSourceBuilder.create().build();
    }

    @Bean(name = "cmSqlSessionFactory")
    @Primary
    public SqlSessionFactory cmSqlSessionFactory(@Qualifier("cmDataSource") DataSource dataSource) throws Exception {
        SqlSessionFactoryBean bean = new SqlSessionFactoryBean();
        bean.setDataSource(dataSource);
        bean.setMapperLocations(new PathMatchingResourcePatternResolver().getResources("classpath:mapper/*.xml"));
        return bean.getObject();
    }

    @Bean(name = "cmTransactionManager")
    @Primary
    public DataSourceTransactionManager cmTransactionManager(@Qualifier("cmDataSource") DataSource dataSource) {
        return new DataSourceTransactionManager(dataSource);
    }

    @Bean(name = "cmSqlSessionTemplate")
    @Primary
    public SqlSessionTemplate cmSqlSessionTemplate(@Qualifier("cmSqlSessionFactory") SqlSessionFactory sqlSessionFactory) throws Exception {
        return new SqlSessionTemplate(sqlSessionFactory);
    }
}
