package com.caimei.config;

import com.github.xiaoymin.knife4j.spring.annotations.EnableKnife4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

/**
 * `@EnableOpenApi`: 用于开启Swagger的自动配置
 *
 * @author Aslee
 * @date 2021/3/10
 */
@Configuration
@EnableSwagger2
@EnableKnife4j
public class SwaggerConfig {
    @Value(value = "${swagger.enabled}")
    Boolean swaggerEnabled;

    @Bean
    public Docket createRestApi(){
        return new Docket(DocumentationType.SWAGGER_2)
                .apiInfo(apiInfo())
                // 是否开启swagger
                .enable(swaggerEnabled)
                .select()
                // 扫描api
                .apis(RequestHandlerSelectors.basePackage("com.caimei.controller").or(RequestHandlerSelectors.basePackage("com.caimei.wxController")))
                .paths(PathSelectors.any())
                .build();
    }

    private ApiInfo apiInfo(){
        return new ApiInfoBuilder().
                // 标题
                title("正品联盟后台API")
                // 描述
                .description("正品联盟后台API")
                // 服务地址
                .termsOfServiceUrl("/doc.html, /swagger-ui/index.html")
                // 版本号
                .version("1.0.0")
                .build();
    }
}
