package com.caimei.config;

import com.caimei.components.RedisService;
import com.caimei.mapper.cmMapper.ClubMapper;
import com.caimei.mapper.cmMapper.LoginMapper;
import com.caimei.model.vo.WxClubUserVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/21
 */
@Component
public class WxApiInterceptor implements HandlerInterceptor {

    private RedisService redisService;

    @Autowired
    public void setRedisService(RedisService redisService) {
        this.redisService = redisService;
    }

    @Resource
    private LoginMapper loginMapper;

    @Resource
    private ClubMapper clubMapper;

    @Value("${caimei.zplmapi}")
    private String zplmapi;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        String token = request.getHeader("X-Token");
        String cacheValue = null != token ? (null != redisService.get(token) ? String.valueOf(redisService.get(token)) : null) : null;
        // 验证机构用户是否可以登录
        WxClubUserVo clubUser = null;
        if (null != cacheValue && cacheValue.contains(",")) {
            // 订阅号登录用户
            String[] cacheArr = cacheValue.split(",");
            String mobile = cacheArr[0];
            Integer authUserId = Integer.parseInt(cacheArr[1]);
            clubUser = clubMapper.getWxClubUser(mobile, null, authUserId, null, null);
        } else if (null != cacheValue && cacheValue.contains("|")){
            // 服务号登录用户
            String[] cacheArr = cacheValue.split("\\|");
            String openId = cacheArr[0];
            String appId = cacheArr[1];
            clubUser = loginMapper.getClubUserByOpenId(openId, appId);
        }
        if (null == cacheValue || null == clubUser) {
            // Token失效
            response.sendRedirect(zplmapi + "/unauthorized");
            return false;
        }
        return true;
    }

}
