package com.caimei.controller.admin.auth;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyuncs.utils.StringUtils;
import com.caimei.model.ResponseJson;
import com.caimei.service.auth.LogisticsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

/**
 * 物流API
 *
 * @author : Aslee
 * @date : 2022/6/15
 */
@Api(tags = "物流API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/logistics")
public class LogisticsApi {

    private final LogisticsService logisticsService;


    @ApiOperation("寄送授权牌")
    @ApiImplicitParam(name = "params", value = "authId:授权id;companyId:物流公司id；logisticsNumber:快递单号；" +
            "imageList:图片备注列表；remarks:备注；mobile:收货人手机号", required = true)
    @PostMapping("/certificate/send")
    public ResponseJson send(@RequestBody String params) {
        JSONObject paramsMap = JSONObject.parseObject(params);
        Integer authId = paramsMap.getInteger("authId");
        Integer companyId = paramsMap.getInteger("companyId");
        String logisticsNumber = paramsMap.getString("logisticsNumber");
        String imageParam = paramsMap.getString("imageList");
        JSONArray imageList = null;
        if (StringUtils.isNotEmpty(imageParam)) {
            imageList = JSONObject.parseArray(imageParam);
        }
        String remarks = paramsMap.getString("remarks");
        String mobile = paramsMap.getString("mobile");
        return logisticsService.sendCertificate(authId, companyId, logisticsNumber, imageList, remarks, mobile);
    }

    @ApiOperation("寄送授权牌物流详情")
    @ApiImplicitParam(name = "authId", value = "授权id", required = true)
    @GetMapping("/certificate/details")
    public ResponseJson certificateLogistics(Integer authId) {
        return logisticsService.certificateLogistics(authId);
    }

    @ApiOperation("物流公司数据")
    @GetMapping("/company/data")
    public ResponseJson getLogisticsCompany() {
        return logisticsService.getLogisticsCompany();
    }

}
