package com.caimei.controller.admin.auth;

import com.caimei.annotation.CurrentUser;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.PasswordDto;
import com.caimei.model.po.SysUser;
import com.caimei.model.vo.UserLoginVo;
import com.caimei.service.auth.UserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.Map;


/**
 * 用户公共API
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Api(tags = "用户公共API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user")
public class UserApi {

    private final UserService userService;

    /**
     * 登录(用户名/手机号，密码)
     */
    @ApiOperation("登录(用户名/手机号，密码)")
    @ApiImplicitParam(name = "params", value = "mobileOrName:手机号或用户名;password:密码", required = true)
    @PostMapping("/login/password")
    public ResponseJson<UserLoginVo> passwordLogin(@RequestBody Map<String,String> params) {
        String mobileOrName = params.get("mobileOrName");
        String password = params.get("password");
        return userService.passwordLogin(mobileOrName,password);
    }

    /**
     * 修改密码
     * @param passwordDto {
     *                           oldPassword        旧密码
     *                           newPassword        新密码
     *                           confirmPwd         确认密码
     * }
     */
    @ApiOperation("修改密码")
    @PostMapping("/update/password")
    public ResponseJson updatePassword(@CurrentUser SysUser sysUser, @RequestBody PasswordDto passwordDto) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 供应商和子用户都可以修改密码，直接取id即可
        Integer authUserId = sysUser.getId();
        if (null == authUserId) {
            return ResponseJson.error("用户id不能为空", null);
        }
        passwordDto.setAuthUserId(authUserId);
        return userService.updatePassword(passwordDto);
    }
}
