package com.caimei.controller.admin.data;

import com.alibaba.fastjson.JSONObject;
import com.caimei.annotation.CurrentUser;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.SysUser;
import com.caimei.model.vo.FileTreeVo;
import com.caimei.service.data.DatabaseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;


import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;

/**
 * @author zzj
 */
@Api(tags = "资料库Api")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/database")
public class DatabaseApi {

    private final DatabaseService databaseService;

    @ApiOperation("获取当前路径下文件")
    @ApiImplicitParam(name = "fileId", required = true, value = "文件Id")
    @GetMapping("/path/file")
    public ResponseJson<List<FileTreeVo>> getFileById(@CurrentUser SysUser sysUser, Integer fileId) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return databaseService.getFileById(fileId, authUserId);
    }

    @ApiOperation("获取文件详情")
    @ApiImplicitParam(name = "fileId", required = true, value = "文件Id")
    @GetMapping("/file/detail")
    public ResponseJson<FileTreeVo> getFileDetail(@CurrentUser SysUser sysUser, Integer fileId) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return databaseService.getFileDetail(fileId, authUserId);
    }

    @ApiOperation("面包屑")
    @ApiImplicitParam(name = "fileId", required = true, value = "当前文件夹Id")
    @GetMapping("/path/crumbs")
    public ResponseJson<FileTreeVo> getCrumbs(@CurrentUser SysUser sysUser, Integer fileId) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return databaseService.getCrumbs(fileId, authUserId);
    }

    @ApiOperation("创建文件夹")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fileId", required = true, value = "当前文件夹Id"),
            @ApiImplicitParam(name = "fileName", required = true, value = "文件夹名称")
    })
    @PostMapping("/path/package")
    public ResponseJson createPackage(@CurrentUser SysUser sysUser, @RequestBody String param) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        JSONObject jsonObject = JSONObject.parseObject(param);
        Integer fileId = jsonObject.getInteger("fileId");
        String fileName = jsonObject.getString("fileName");
        return databaseService.createPackage(authUserId, fileId, fileName);
    }

    @ApiOperation("修改文件/文件夹名")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fileId", required = true, value = "当前文件夹Id"),
            @ApiImplicitParam(name = "fileName", required = true, value = "修改的文件名称"),
            @ApiImplicitParam(name = "packageType", required = true, value = "0是文件夹，1是文件")
    })
    @PostMapping("/update/fileName")
    public ResponseJson updatePackage(@RequestBody String params) {
        JSONObject parseObject = JSONObject.parseObject(params);
        Integer fileId = parseObject.getInteger("fileId");
        String fileName = parseObject.getString("fileName");
        Integer packageType = parseObject.getInteger("packageType");
        return databaseService.updatePackage(fileId, fileName, packageType);
    }

    @ApiOperation("移动文件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fileId", required = true, value = "当前文件Id"),
            @ApiImplicitParam(name = "parentId", required = true, value = "目标文件夹Id")
    })
    @PostMapping("/move/package")
    public ResponseJson movePackage(@RequestBody String param) {
        JSONObject jsonObject = JSONObject.parseObject(param);
        String fileId = jsonObject.getString("fileId");
        Integer parentId = jsonObject.getInteger("parentId");
        return databaseService.movePackage(fileId, parentId);
    }

    @ApiOperation("文件夹目录")
    @GetMapping("/file/tree")
    public ResponseJson<FileTreeVo> getPackageTree(@CurrentUser SysUser sysUser) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return databaseService.getPackageTree(authUserId);
    }

    @ApiOperation("下载文件夹")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fileId", required = true, value = "当前文件夹Id"),
            @ApiImplicitParam(name = "fileName", required = true, value = "文件夹名称")
    })
    @GetMapping("/path/package/zip")
    public ResponseJson downLoadPackageZip(@CurrentUser SysUser sysUser, Integer fileId, String fileName, HttpServletResponse response) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return databaseService.downLoadZip(fileId, fileName, authUserId, response);
    }

    @ApiOperation("勾选文件下载")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fileId", required = true, value = "勾选文件Id,逗号分隔")
    })
    @GetMapping("/path/chose/zip")
    public ResponseJson downLoadChoseZip(@CurrentUser SysUser sysUser, String fileId, HttpServletResponse response) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return databaseService.downLoadChoseZip(fileId, authUserId, response);
    }

    @ApiOperation("删除文件")
    @ApiImplicitParam(name = "fileId", required = true, value = "当前文件Id")
    @PostMapping("/delete/file")
    public ResponseJson deleteFiles(@RequestBody String fileId) {
        JSONObject jsonObject = JSONObject.parseObject(fileId);
        String fil = jsonObject.getString("fileId");
        return databaseService.deleteFiles(fil);
    }

    @ApiOperation("上传结果")
    @ApiImplicitParam(name = "params", required = true, value = "fileName:文件原名;ossName:阿里云文件名：ossUrl:阿里云文件url;fileSize：文件大小;parentId:父级文件夹id;mime:文件application")
    @PostMapping("/oss/upload/result")
    public ResponseJson getOssUploadResult(@CurrentUser SysUser sysUser, @RequestBody String params) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        JSONObject parseObject = JSONObject.parseObject(params);
        String fileName = parseObject.getString("fileName");
        String ossName = parseObject.getString("ossName");
        String ossUrl = parseObject.getString("ossUrl");
        String fileSize = parseObject.getString("fileSize");
        Integer parentId = parseObject.getInteger("parentId");
        String mime = parseObject.getString("mime");
        return databaseService.getOssUploadResult(authUserId, fileName, ossName, ossUrl, fileSize, parentId,mime);
    }

    @ApiOperation("获取阿里云token")
    @GetMapping("/oss/token")
    public ResponseJson<HashMap<String, String>> ossTokenGet() {
        return databaseService.ossTokenGet();
    }
}
