package com.caimei.controller.admin.sys;

import com.caimei.annotation.CurrentUser;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.SysRole;
import com.caimei.model.po.SysUser;
import com.caimei.service.sys.SysRoleService;
import com.github.pagehelper.PageInfo;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/1/6
 */
@RestController
@RequestMapping("/sys/role")
public class SysRoleApi {

    @Resource
    private SysRoleService sysRoleService;

    /**
     * 获取角色列表
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    @GetMapping("/list")
    public ResponseJson<PageInfo<SysRole>> roleList(@CurrentUser SysUser sysUser, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                    @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        return sysRoleService.getRoleList(authUserId, pageNum, pageSize);
    }

    /**
     * 根据ID获取角色
     */
    @GetMapping("/{id}")
    public ResponseJson<SysRole> getRole(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("角色Id不能为空！", null);
        }
        return sysRoleService.getRoleInfo(id);
    }

    /**
     * 根据ID更新角色
     */
    @PostMapping("/update/{id}")
    public ResponseJson<Void> updateRole(@PathVariable("id") Integer id, @RequestBody SysRole sysRole) {
        if (null == id || id <= 0) {
            return ResponseJson.error("角色Id不能为空！", null);
        }
        return sysRoleService.updateRole(id, sysRole);
    }

    /**
     * 添加角色
     */
    @PostMapping("/create")
    public ResponseJson<Void> addRole(@CurrentUser SysUser sysUser, @RequestBody SysRole sysRole) {
        if (null == sysUser) {
            return ResponseJson.error("用户信息异常", null);
        }
        // 获取供应商用户id
        Integer userIdentity = sysUser.getUserIdentity();
        Integer authUserId = 2 == userIdentity ? sysUser.getId() : 3 == userIdentity ? sysUser.getParentId() : null;
        sysRole.setAuthUserId(authUserId);
        sysRole.setRoleType(1 == userIdentity ? 1 : 3);
        return sysRoleService.addRole(sysRole);
    }

    /**
     * 根据ID删除角色
     */
    @PostMapping("/delete/{id}")
    public ResponseJson<Void> deleteRole(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("角色Id不能为空！", null);
        }
        return sysRoleService.deleteRole(id);
    }

    /**
     * 角色授权菜单
     */
    @PostMapping("/auth/{id}")
    public ResponseJson<Void> setRoleMenu(@PathVariable("id") Integer id, @RequestBody SysRole sysRole) {
        if (null == id || id <= 0) {
            return ResponseJson.error("角色Id不能为空！", null);
        }
        if (!StringUtils.hasLength(sysRole.getMenuIds())){
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return sysRoleService.setRoleMenu(id, sysRole);
    }

}
