package com.caimei.controller.wechat;

import com.alibaba.fastjson.JSONObject;
import com.caimei.annotation.Idempotent;
import com.caimei.model.ResponseJson;
import com.caimei.model.vo.ProductFormVo;
import com.caimei.model.vo.WxClubUserVo;
import com.caimei.service.auth.AuthProductService;
import com.caimei.service.wechat.RegisterService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;



/**
 * 机构用户登录API
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Api(tags = "微信机构用户注册API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/wx/user/register")
public class RegisterApi {

    private final RegisterService registerService;

    private final AuthProductService authProductService;

    @ApiOperation("普通注册")
    @ApiImplicitParam(name = "params", value = "mobile:手机号；verifyCode:验证码；password:密码；authUserId:供应商用户id；", required = true)
    @PostMapping("/simple")
    public ResponseJson<WxClubUserVo> simpleRegister(@RequestBody String params) {
        JSONObject parseObject = JSONObject.parseObject(params);
        String mobile = parseObject.getString("mobile");
        String verifyCode = parseObject.getString("verifyCode");
        String password = parseObject.getString("password");
        Integer authUserId = parseObject.getInteger("authUserId");
        Integer authId = parseObject.getInteger("authId");
        // 注册类型：1密码注册，2验证码注册（默认密码，短信推送）
        int registerType = 1;
        if (null != authId && StringUtils.isEmpty(password)) {
            registerType = 2;
        }
        if (StringUtils.isEmpty(mobile)) {
            return ResponseJson.error("手机号不能为空", null);
        }
        if (StringUtils.isEmpty(verifyCode)) {
            return ResponseJson.error("验证码不能为空", null);
        }
        if (1 == registerType && StringUtils.isEmpty(password)) {
            return ResponseJson.error("密码不能为空", null);
        }
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        return registerService.simpleRegister(mobile, verifyCode, password, authUserId, authId, registerType);
    }

    @ApiOperation("全部注册")
    @ApiImplicitParam(name = "params", value = "registerType:1机构用户注册，2机构认证，3设备认证；" +
            "authUserId:供应商用户id；" +
            "authId:机构id；" +
            "clubUserId:机构用户id；" +
            "clubUserInfo:机构用户数据；" +
            "authInfo:机构数据；" +
            "productInfo：设备数据", required = true)
    @Idempotent(prefix = "idempotent_club_user", keys = {"#params"}, expire = 5)
    @PostMapping("/all")
    public ResponseJson allRegister(@RequestBody String params) {
        JSONObject parseObject = JSONObject.parseObject(params);
        // 注册类型，以逗号分割
        String registerType = parseObject.getString("registerType");
        if (StringUtils.isEmpty(registerType)) {
            return ResponseJson.error("注册类型不能为空", null);
        }
        // 供应商用户id
        Integer authUserId = parseObject.getInteger("authUserId");
        if (null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        Integer clubUserId = parseObject.getInteger("clubUserId");
        Integer authId = parseObject.getInteger("authId");
        // 机构用户数据
        String clubUserInfo = parseObject.getString("clubUserInfo");
        // 认证机构数据
        String authInfo = parseObject.getString("authInfo");
        // 认证设备数据
        String productInfo = parseObject.getString("productInfo");
        if (null == productInfo) {
            return ResponseJson.error("认证设备数据异常", null);
        }
        return registerService.allRegister(authUserId, clubUserId, authId, registerType, clubUserInfo, authInfo, productInfo);
    }


    @ApiOperation("关联设备获取设备信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "productId", required = false, value = "设备id"),
            @ApiImplicitParam(name = "snCode", required = false, value = "sn码")
    })
    @GetMapping("/product/info")
    public ResponseJson<ProductFormVo> getProductDetails(Integer productId, String snCode) {
        if (null == productId && null == snCode) {
            return ResponseJson.error("设备id和sn码不能同时为空", null);
        }
        return authProductService.getProductInfo(productId, snCode);
    }
}
