package com.caimei.listener;


import com.alibaba.fastjson.JSONObject;
import com.caimei.model.po.IpSavePo;
import com.caimei.service.aopservice.IpSaveService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.rocketmq.spring.annotation.RocketMQMessageListener;
import org.apache.rocketmq.spring.core.RocketMQListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @author Administrator
 */
@Slf4j
@Component
@RocketMQMessageListener(
        topic = "zpIp",
        // messageModel = MessageModel.BROADCASTING,//指定为广播消费
        // consumeMode = ConsumeMode.ORDERLY, // 指定消费模式为顺序消费，消费的顺序也和发送顺序一致
        // selectorType = SelectorType.TAG,// 如果我们的生产者指定了Tag，但是消费者的selectorExpression没有设置，即用默认的“*”,那么这个消费者也会消费到
        // selectorExpression = "tag",     // 指定了tag后，发送的消息如果不带tag，将会消费不到
        consumerGroup = "Zp_group")
public class IpSaveListener implements RocketMQListener<String> {

    @Autowired
    private IpSaveService ipSaveService;

    @Override
    public void onMessage(String message) {
        log.info("{}收到消息：{}", this.getClass().getSimpleName(), message);
        JSONObject jsonObject = JSONObject.parseObject(message);
        //ip,接口路径，接口参数，注解名
        String ip = (String) jsonObject.get("ip");
        String path = (String) jsonObject.get("URI");
        String param = (String) jsonObject.get("queryString");
        String saveName = (String) jsonObject.get("saveName");
        IpSavePo ipSavePo = new IpSavePo();
        if (StringUtils.isNotBlank(path)) {
            ipSavePo.setRequestUrl(path);
        }
        if (StringUtils.isNotBlank(saveName)) {
            ipSavePo.setPortName(saveName);
        }
        if (StringUtils.isNotBlank(ip)) {
            ipSavePo.setIp(ip);
        }
        if(StringUtils.isNotBlank(param)){
            ipSavePo.setParams(param);
        }
        SimpleDateFormat format = new SimpleDateFormat("yyyyMMddHHmmss");
        String nowDate = format.format(new Date());
        Long aLong = Long.valueOf(nowDate);
        ipSavePo.setSaveTime(aLong);
        ipSaveService.save(ipSavePo);
    }
}
