package com.caimei.mapper.cmMapper;


import com.caimei.model.po.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/12/2
 */
@Mapper
public interface SystemMapper {
    /**
     * 根据用户名称查找可登录用户
     */
    SysUser findByUsername(@Param("username") String username);
    /**
     * 根据用户Id查找可登录用户
     */
    SysUser findByUserId(Integer authUserId);
    Integer getUserIdByUsername(String username);
    /**
     * 新增用户角色关系表
     */
    void insertUserRoleRelation(Integer userId, Integer roleId);
    /**
     * 获取用户角色名称列表
     */
    List<String> getRoleNamesByUserId(Integer userId);
    /**
     * 获取用户角色Id列表
     */
    List<String> getRoleIdsByUserId(Integer userId);
//    /**
//     * 获取用户角色Id列表
//     */
//    List<Integer> getRoleIdsByUsername(String username);
    /**
     * 删除用户原有角色关联
     */
    void deleteUserRoleRelation(Integer userId);
    /**
     * 根据角色Ids获取菜单列表
     */
    List<SysMenu> getMenusByRoleIds(@Param("roleIds") List<Integer> roleIds);
    /**
     * 根据角色Id获取按钮权限列表
     */
    List<String> getPermissionNames(@Param("roleIds") List<Integer> roleIds);

    /**
     * 获取用户列表
     */
    List<SysUser> getUserList(Integer authUserId, String username, String linkMan);
    /**
     * 根据ID获取用户
     */
    SysUser getUser(Integer id);
    /**
     * 根据ID更新用户
     */
    void updateSysUser(SysUser sysUser);
    /**
     * 根据ID删除用户
     */
    void deleteSysUser(Integer id);

    /**
     * 根据用户Id获取用户角色列表
     */
    List<SysRole> getRoleListByUserId(Integer userId);
    /**
     * 获取角色列表
     * @param authUserId
     */
    List<SysRole> getRoleList(Integer authUserId);
    /**
     * 根据ID获取角色
     */
    SysRole getRole(Integer id);
    /**
     * 根据角色名称获取角色
     */
    SysRole getRoleByRoleName(@Param("authUserId") Integer authUserId, @Param("roleName") String roleName);
    /**
     * 根据ID更新角色
     */
    void updateRole(SysRole sysRole);
    /**
     * 添加角色
     */
    void insertRole(SysRole sysRole);
    /**
     * 根据ID删除角色
     */
    void deleteRole(Integer id);
    /**
     * 根据角色ID获取菜单Ids
     */
    List<Integer> getMenuIdsByRoleId(Integer roleId);
    /**
     * 根据角色ID获取（权限-菜单）Ids
     */
    List<String> getPermissionMenuIdsByRoleId(Integer roleId);
    /**
     * 保存角色菜单关系
     */
    void insertRoleMenuRelation(Integer roleId, Integer menuId);
    /**
     * 保存角色权限关系
     */
    void insertRolePermissionRelation(Integer roleId, Integer permissionId);
    /**
     * 删除原有角色菜单关联
     */
    void deleteRoleMenuRelation(Integer roleId);
    /**
     * 删除原有角色权限关联
     */
    void deleteRolePermissionRelation(Integer roleId);

    /**
     * 获取菜单列表
     *
     * @param parentId 父级菜单Id
     * @param status   状态：0启用，1停用
     */
    List<SysMenu> getMenuList(Integer parentId, Integer menuType, Integer status);
    /**
     * 获取树状菜单列表
     * @param parentId 父级菜单Id
     */
    List<SysMenuTree> getMenuTree(String parentId, Integer menuType);
    /**
     * 获取当前菜单的按钮权限
     * @param menuId 菜单Id
     */
    List<SysMenuTree> getTreePermissions(String menuId);
    /**
     * 根据ID获取菜单
     */
    SysMenu getMenu(Integer id);
    /**
     * 根据路由名称查询菜单
     */
    SysMenu getMenuByName(Integer menuType, String name);
    /**
     * 根据ID更新菜单
     */
    void updateMenu(SysMenu menu);
    /**
     * 根据ID删除菜单
     */
    void deleteMenu(Integer id);
    /**
     * 添加菜单
     */
    void insertMenu(SysMenu menu);
    /**
     * 获取菜单的按钮权限列表
     * @param menuId 菜单Id
     */
    List<SysPermission> getPermissionList(Integer menuId);
    /**
     * 根据菜单Id获取权限ids
     */
    List<Integer> getPermissionIds(Integer menuId);
    /**
     * 权限ID更新权限
     */
    void updatePermission(SysPermission permission);
    /**
     * 权限ID删除权限
     */
    void deletePermission(Integer id);
    /**
     * 添加按钮权限
     */
    void insertPermission(SysPermission permission);

    void insertUser(SysUser sysUser);

    /**
     * 根据菜单id查询会员菜单角色id
     */
    Integer getVipRoleIdByMenuId(Integer menuId);

    /**
     * 更新供应商菜单
     * @param menu
     */
    void updateShopMenu(SysMenu menu);

    List<SysMenu> getVipMenuList();

    List<Integer> getVipRoleIdList(Integer authUserId);

    Integer getMenuParentId(Integer id);

    void deleteVipRoleMenuRelation(Integer menuId);

    void deleteRoleMenuPermission(Integer menuId);

    void deleteMenuRoleRelation(Integer menuId);

    List<Integer> getMenuIdList(String parentId, int menuType);

    void updateUserStatus(@Param("id") Integer id, @Param("status") Integer status);

    List<SysRole> getShopRoleList(Integer authUserId);

    /**
     * 获取基础菜单列表
     * @param roleId
     * @return
     */
    List<SysMenu> getBaseMenuList(Integer roleId);

    /**
     * 获取供应商菜单对应的角色id
     */
    Integer getShopRoleIdByMenuId(Integer menuId);

    SysUser findByMobile(String mobile);

    SysUser findByLoginAccount(String loginAccount);
}
