package com.caimei.service.async;

import com.caimei.config.FastDfsClient;
import com.caimei.mapper.cmMapper.ArticleMapper;
import com.caimei.mapper.cmMapper.FileMapper;
import com.caimei.model.po.ArticlePo;
import com.caimei.model.vo.ArticleFormVo;
import com.caimei.model.vo.FileTreeVo;
import com.caimei.utils.FileZipUtils;
import com.caimei.utils.OSSUtils;
import lombok.extern.slf4j.Slf4j;
import net.coobird.thumbnailator.Thumbnails;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;
import org.springframework.util.Assert;

import javax.annotation.Resource;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.UUID;

/**
 * @author zzj
 */
@Slf4j
@Component
public class AsyncService {


    @Value("${spring.profiles.active}")
    private String active;

    @Value("${caimei.zpapi}")
    private String zpapi;

    @Resource
    private FileMapper fileMapper;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    @Resource
    private FastDfsClient client;

    @Resource
    private ArticleMapper articleMapper;

    @Async("taskExecutor")
    public void saveArticleImage(boolean insertFlag, ArticlePo article, Integer parentId) {
        //保存文章相关属性
        FileTreeVo fileTreeVo = new FileTreeVo();
        fileTreeVo.setPackageType(1);
        fileTreeVo.setMime("text/plain");
        fileTreeVo.setFileName(article.getTitle() + ".txt");
        fileTreeVo.setFileType("article");
        fileTreeVo.setParentId(parentId);
        fileTreeVo.setAuthUserId(article.getAuthUserId());
        fileTreeVo.setArticleId(article.getId());
        UUID uuid = UUID.randomUUID();
        fileTreeVo.setOssName(uuid + ".txt");
        //http://192.168.2.92:8888/:authUserId/:prefix/docs/article-detail?fileId=fileId
        String prefix = fileMapper.findShopPrefix(article.getAuthUserId());
        prefix = null == prefix ? "app" : prefix;
        String path = "";
        path = "/" + article.getAuthUserId() + "/" + prefix + "/docs/article-detail?articleId=" + article.getId();
        if ("dev".equals(active)) {
            path = "http://192.168.2.92:8888" + path;
        } else {
            path = zpapi + path;
        }
        if (2 == article.getArticleType()) {
            path = article.getArticleLink();
        }
        fileTreeVo.setOssUrl(path);
        //创建txt文件保存链接上传到阿里云
        String delPath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempFile/" + uuid;
        String filePath = delPath + "/";
        if ("dev".equals(active)) {
            delPath = "D:\\caimei-workSpace\\file\\" + uuid;
            filePath = delPath + "\\";
        }
        File file = writeTxt(filePath, path);
        OSSUtils.ossUpload(fileTreeVo.getOssName(), file, "text/plain", null);
        try {
            client.downloadFile(article.getImage(), filePath + "myShotImage.jpg");
            log.info("下载成功？？？");
            Thumbnails.of(filePath + "myShotImage.jpg").size(64, 64).toFile(filePath + "NewMyShotImage.jpg");
            String imgUrl = imageDomain + "/" + client.uploadFile(filePath + "NewMyShotImage.jpg");
            fileTreeVo.setScreenshot(imgUrl);
        } catch (IOException e) {
            e.printStackTrace();
        }
        if (insertFlag) {
            fileMapper.insertNewFile(fileTreeVo);
        } else {
            FileTreeVo fil = fileMapper.findFileByArticleId(article.getId());
            if (StringUtils.isNotBlank(fil.getScreenshot())) {
                client.deleteFile(fil.getScreenshot());
            }
            if (StringUtils.isNotBlank(fil.getOssName())) {
                OSSUtils.deleteSingleFile(fil.getOssName());
            }
            fileMapper.updateFileByArticleId(fileTreeVo);
        }
        File fileDir = new File(delPath);
        Boolean aBoolean = FileZipUtils.deleteFile(fileDir);
        log.info("临时txt删除------------>" + aBoolean);
    }

    private File writeTxt(String filePath, String content) {
        File fileDir = new File(filePath);
        boolean mkdirs = fileDir.mkdirs();
        Assert.isTrue(mkdirs, "文件夹创建失败");
        FileWriter fw = null;
        File file = new File(filePath + "1.txt");
        try {
            if (!file.exists()) {
                file.createNewFile();
            }
            fw = new FileWriter(filePath + "1.txt");
            BufferedWriter bw = new BufferedWriter(fw);
            bw.write(content);
            bw.close();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                fw.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return file;
    }

    public void insertScreenshot(FileTreeVo fileTreeVo) {
        UUID uuid = UUID.randomUUID();
        String delPath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempFile/" + uuid;
        String filePath = delPath + "/" + fileTreeVo.getFileName();
        String newImage = delPath + "/";
        String imgUrl = "";
        if ("dev".equals(active)) {
            delPath = "D:\\caimei-workSpace\\file\\" + uuid;
            filePath = delPath + "\\" + fileTreeVo.getFileName();
            newImage = delPath + "\\";
        }
        File fileDir = new File(delPath);
        boolean mkdirs = fileDir.mkdirs();
        Assert.isTrue(mkdirs, "文件夹创建失败");

        OSSUtils.downFileByFilePath("authFile/", fileTreeVo.getOssName(), filePath);
        try {
            Thumbnails.of(filePath).size(64, 64).toFile(newImage + "newImages." + fileTreeVo.getFileType());
            imgUrl = imageDomain + "/" + client.uploadFile(newImage + "newImages." + fileTreeVo.getFileType());
        } catch (IOException e) {
            log.error("压缩图失败：" + e);
        }
        fileTreeVo.setScreenshot(imgUrl);
        fileMapper.insertImgUrl(fileTreeVo);
        FileZipUtils.deleteFile(fileDir);
    }
}
