package com.caimei.service.auth;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.ArticleFormVo;
import com.caimei.model.vo.ArticleListVo;
import com.caimei.model.vo.WxArticleListVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/8
 */
public interface ArticleService {

    /**
     * 获取文章列表
     *
     * @param listType     列表类型：1文章列表，2文章审核列表
     * @param authUserId   供应商用户id
     * @param articleTitle 文章标题
     * @param auditStatus  审核状态
     * @param status       上线状态
     * @param pageNum      第几页
     * @param pageSize     一页多少条
     * @return ArticleVo
     */
    ResponseJson<PageInfo<ArticleListVo>> getArticleList(Integer listType, Integer authUserId, String articleTitle, Integer auditStatus, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 添加/编辑文章
     *
     * @param articleId      文章id
     * @param authUserId     供应商用户id
     * @param articleTitle   文章标题
     * @param articleImage   文章图片
     * @param articleContent 文章内容
     * @param sort
     * @param parentId       父级文件夹id
     * @return ResponseJson
     */
    ResponseJson saveArticle(Integer articleId, Integer authUserId, String articleTitle, String articleImage, String articleContent, Integer sort, Integer parentId,Integer articleType,String articleLink);

    /**
     * 更新文章状态
     *
     * @param articleId 文章id
     * @param status    文章状态:0停用 1启用
     * @return ResponseJson
     */
    ResponseJson updateArticleStatus(Integer articleId, Integer status);

    /**
     * 删除文章
     *
     * @param articleId 文章id
     * @return ResponseJson
     */
    ResponseJson deleteArticle(Integer articleId);

    /**
     * 审核文章
     *
     * @param articleId     文章id
     * @param auditStatus   审核状态：0审核未通过，1审核通过，2待审核
     * @param invalidReason 审核不通过原因
     * @param auditBy       审核人用户id
     * @return
     */
    ResponseJson auditArticle(Integer articleId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 文章回显数据
     *
     * @param articleId 文章id
     * @return
     */
    ResponseJson<ArticleFormVo> getArticleFormData(Integer articleId);

    /**
     * 微信公众号文章列表
     *
     * @param authUserId   供应商用户id
     * @param articleTitle 文章名称
     * @param pageNum      第几页
     * @param pageSize     一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxArticleListVo>> getWxArticleList(Integer authUserId, String articleTitle, Integer pageNum, Integer pageSize);

    /**
     * 更改查看标记
     *
     * @param articleId
     * @return
     */
    ResponseJson checkArticle(Integer articleId);

    /**
     * 更改排序值
     */
    ResponseJson updateSort(Integer articleId, Integer sort);
}
