package com.caimei.service.auth;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.*;
import com.github.pagehelper.PageInfo;

import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface AuthClubService {

    /**
     * 机构列表
     *
     * @param authUserId    供应商用户id
     * @param authParty      机构名称
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return AuthVo
     */
    ResponseJson<PageInfo<ClubVo>> getClubList(Integer authUserId, String authParty, Integer pageNum, Integer pageSize);

    /**
     * 机构用户列表
     * @param authUserId    供应商用户id
     * @param mobile    手机号
     * @param name
     * @param status    状态：1未绑定，2已绑定，3已过期
     * @param pageNum   第几页
     * @param pageSize  一页多少条
     * @return  ClubUserVo
     */
    ResponseJson<PageInfo<ClubUserVo>> getClubUserList(Integer authUserId, String mobile, String name, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 微信公众号机构列表
     *
     * @param authUserId 供应商用户id
     * @param authParty   机构名称
     * @param pageNum    第几页
     * @param pageSize   一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxClubListVo>> getWxClubList(Integer authUserId, String appId, String lngAndLat, String authParty, Integer provinceId,
                                                       Integer cityId, Integer townId, Integer pageNum, Integer pageSize);

    /**
     * 提交反馈
     * @param clubUserId    机构用户id
     * @param content       反馈内容
     * @return
     */
    ResponseJson submitFeedback(Integer clubUserId, String content);

    /**
     * 微信公众号机构详情
     * @param authId 机构id
     * @return
     */
    ResponseJson<WxClubDetailsVo> getWxClubDetails(Integer authId);

    /**
     * 根据authUserId获取供应商信息
     *
     * @param authUserId
     * @return
     */
    ResponseJson<WxShopVo> getWxShopInfo(Integer authUserId, String appId);

    /**
     * 添加/编辑机构用户
     */
    ResponseJson saveClubUser(Integer clubUserId, Integer authUserId, String mobile);

    /**
     * 删除机构用户
     */
    ResponseJson deleteClubUser(Integer clubUserId);

    /**
     * 更新用户状态
     */
    ResponseJson updateStatus(Integer clubUserId, Integer status);

    /**
     * 重置机构用户密码
     * @param clubUserId
     * @return
     */
    ResponseJson resetClubUserPassword(Integer clubUserId);

    /**
     *
     * @param authUserId
     * @return
     */
    ResponseJson<List<WxClubListVo>> getWxStarClubList(Integer authUserId);

    /**
     *
     * 更换绑定机构
     */

    ResponseJson saveBindAuth(Integer authId,String authParty,Integer authUserId,Integer clubUserId);
}
