package com.caimei.service.auth;

import com.caimei.annotation.CurrentUser;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ProductSaveDto;
import com.caimei.model.po.ProductParamPo;
import com.caimei.model.po.ProductTypePo;
import com.caimei.model.po.SysUser;
import com.caimei.model.vo.*;
import com.github.pagehelper.PageInfo;

import java.io.IOException;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/17
 */
public interface AuthProductService {

    /**
     * 授权商品列表
     *
     *
     * @param listType      列表类型：1商品列表，2商品审核列表
     * @param authId        授权id
     * @param productName   商品名称
     * @param snCode        商品SN码
     * @param status        上线状态：0下线，1上线，2待上线
     * @param auditStatus   审核状态:0审核未通过，1审核通过，2待审核
     * @param shopAuditStatus   供应商审核状态:0审核未通过，1审核通过，2待审核
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  ProductListVo
     */
    ResponseJson<PageInfo<ProductListVo>> getProductList(Integer listType, Integer authId, String productName, String snCode, Integer status, Integer auditStatus, Integer shopAuditStatus, Integer pageNum, Integer pageSize);

    /**
     * 更新授权商品状态
     * @param productId     授权商品id
     * @param status        上线状态：0已下线，1已上线，2待上线
     * @return  ResponseJson
     */
    ResponseJson updateProductStatus(Integer productId, Integer status);

    /**
     * 删除授权商品
     * @param productId     授权商品Id
     * @return  ResponseJson
     */
    ResponseJson deleteProduct(Integer productId);

    /**
     * 添加/编辑授权商品
     *
     * @param productSaveDto {
     *                       productId              授权商品id
     *                       authId                 授权id
     *                       productName            商品名称
     *                       snCode                 商品SN码
     *                       productImage           商品图片
     *                       certificateImage       授权牌照
     *                       status                 上线状态：0已下线，1已上线，2待上线
     *                       createBy               创建人id
     *                       paramList              商品参数列表
     *                       }
     * @return ResponseJson
     */
    ResponseJson saveProduct(ProductSaveDto productSaveDto) throws IOException;

    /**
     * 添加/编辑授权商品(关联机构设备保存)
     * @param authId
     * @return
     */
    ResponseJson saveProductAndRelaTion(Integer authId,List<String> snlist,Integer authType) throws IOException;

    /**
     * 获取授权商品回显数据
     *
     * @param relationId     机构设备关联id
     * @return  ProductFormVo
     */
    ResponseJson<ProductFormVo> getProductFormData(Integer relationId);

    /**
     * 根据品牌授权id获取商品id列表
     * @param authId 授权id
     * @return  Integer
     */
    List<Integer> getProductIdsByAuthId(Integer authId);

    /**
     * 更新所有商品的水印图片
     * @return  ResponseJson
     */
    ResponseJson updateAllWaterMark();

    /**
     * 审核商品
     *
     * @param productId         商品id
     * @param auditStatus       审核状态
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @param source
     * @return ResponseJson
     */
    ResponseJson auditProduct(Integer productId, Integer auditStatus, String invalidReason, Integer auditBy, Integer source);


    /**
     * 微信公众号机构列表
     *
     * @param listType
     * @param authParty
     * @param productTypeId         设备分类id
     * @param snCode   sn码后四位
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxProductListVo>> getWxProductList(Integer listType, Integer authId, String authParty, Integer productTypeId, String snCode, Integer pageNum, Integer pageSize);

    /**
     * 认证商品详情
     * @param productId     商品id
     * @return
     */
    ResponseJson<AuthProductVo> getAuthProductDetails(Integer productId);

    /**
     * 保存设备分类
     */
    ResponseJson<ProductTypePo> saveProductType(Integer productTypeId, Integer authUserId, Integer infoId, String name, String image, Integer createBy, List<ProductParamPo> paramList, Integer createSource) throws IOException;

    /**
     * 删除设备分类
     */
    ResponseJson deleteProductType(Integer productTypeId);

    /**
     * 更新设备分类状态
     */
    ResponseJson updateProductTypeStatus(Integer productTypeId, Integer status);

    /**
     * 获取设备分类列表
     */
    ResponseJson<PageInfo<ProductTypeListVo>> getProductTypeList(Integer listType, Integer authUserId, String name, Integer status, Integer auditStatus, Integer pageNum, Integer pageSize);

    /**
     * 获取设备分类下拉框列表
     */
    ResponseJson<List<ProductTypeListVo>> getProductTypeSelectList(Integer authUserId);

    /**
     * 审核设备分类
     */
    ResponseJson auditProductType(Integer productTypeId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 微信设备分类列表
     */
    ResponseJson<PageInfo<WxProductTypeListVo>> getWxProductTypeList(Integer authUserId, String appId, String name, Integer pageNum, Integer pageSize);

    /**
     * 设备分类回显数据
     * @return
     */
    ResponseJson<ProductTypePo> getProductTypeFromData(Integer productTypeId);
    /**
     * 更改查看标记
     * @param productId
     * @return
     */
    ResponseJson checkAuthProduct(Integer productId);

    /**
     * 获取设备详情
     * @param productId
     * @param snCode
     * @return
     */
    ResponseJson<ProductFormVo> getProductInfo(Integer productId, String snCode);

    /**
     * sn码列表
     * @param authUserId
     * @param authId
     * @return
     */
    ResponseJson<List<String>> getSnCodeList(Integer authUserId, Integer authId);

    /**
     * sn码列表1
     * @param authUserId
     * @param authId
     * @return
     */
    ResponseJson<List<String>> getSnCodeList1(Integer authUserId, Integer authId);

    /**
     * 更改设备分类查看标记
     * @param productTypeId
     * @return
     */
    ResponseJson checkProductType(Integer productTypeId);
    /**
     * 获取机构下所有的设备信息
     *
     */
    ResponseJson<List<ProductListVo>> getPronductInfo( Integer authId,Integer authUserId);
}


