package com.caimei.service.auth;

import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ShopInfoDto;
import com.caimei.model.po.UserPo;
import com.caimei.model.vo.*;
import com.github.pagehelper.PageInfo;

import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface ShopService {
    /**
     * 供应商列表数据
     * @param listType  列表类型：1供应商列表，2审核列表
     * @param shopName  供应商名称
     * @param loginAccount
     * @param shopType  供应商类型：1品牌方，2代理商
     * @param infoId    品牌信息Id
     * @param mobile    手机号
     * @param linkMan   联系人
     * @param lowerAuditStatus  下级审核状态,0未完成审核，1已完成审核
     * @param pageNum   第几页
     * @param pageSize  一页多少条
     * @return PageInfo<ShopVo>
     */
    ResponseJson<PageInfo<ShopListVo>> getShopList(Integer listType, String shopName, String loginAccount, Integer shopType, Integer infoId, String mobile, String linkMan, Integer lowerAuditStatus, Integer sendStatus, Integer pageNum, Integer pageSize);

    /**
     * 更新供应商状态
     * @param authUserId    供应商用户id
     * @param status    供应商状态
     * @return ResponseJson
     */
    ResponseJson updateShopStatus(Integer authUserId, Integer status);

    /**
     * 重置供应商密码
     * @param authUserId    供应商用户id
     * @return ResponseJson
     */
    ResponseJson resetShopPassword(Integer authUserId);

    /**
     * 添加供应商
     * @param shop {
     *                    shopType           供应商类型：1代理商，2品牌方
     *                    shopName           供应商名称
     *                    mobile             手机号
     *                    linkMan            联系人
     *                    shopStatus         供应商状态：0停用 1启用
     *                    createBy           创建人用户id
     *                    }
     * @param shopInfoList
     */
    ResponseJson saveShop(UserPo shop, List<ShopInfoDto> shopInfoList);

    /**
     * 获取供应商回显数据
     * @param authUserId 供应商用户id
     * @return  ShopVo
     */
    ResponseJson<ShopFormVo> getShopFormData(Integer authUserId);

    /**
     * 品牌信息列表
     * @param authUserId    供应商用户id
     * @return AuthVo
     */
    ResponseJson<List<ShopInfoVo>> getShopInfoList(Integer authUserId);

    /**
     * 产地国家列表
     * @return CountryVo
     */
    ResponseJson<List<CountryVo>> getCountryList();

    /**
     * 用户反馈列表
     * @param authUserId    供应商用户id
     * @param authParty
     * @param mobile
     * @param handleStatus
     * @param pageNum
     * @param pageSize
     * @return
     */
    ResponseJson<PageInfo<FeedbackVo>> getFeedbackList(Integer authUserId, String authParty, String mobile, Integer handleStatus, Integer pageNum, Integer pageSize);

    /**
     * 用户反馈表单数据
     * @param feedbackId    反馈id
     * @return
     */
    ResponseJson<FeedbackVo> getFeedbackFormData(Integer feedbackId);

    /**
     * 处理用户反馈
     * @param feedbackId    反馈id
     * @param handleResult  处理结果
     * @return
     */
    ResponseJson handleFeedback(Integer feedbackId, String handleResult);

    /**
     * 根据供应商id查询供应商下所有品牌
     * @param authUserId    供应商id
     * @return
     */
    List<String> getShopBrands(Integer authUserId);

    /**
     * 发送验证码
     * @param mobile
     * @return
     */
    ResponseJson sendVerifyCode(String mobile);

    /**
     * 更改手机号
     */
    ResponseJson changeMobile(Integer authUserId, String oldMobile, String verifyCode, String newMobile);

    /**
     * 绑定登录账号
     */
    ResponseJson bindLoginAccount(Integer authUserId, String mobile, String verifyCode, String loginAccount);

    /**
     * 更新供应商下所有机构授权牌
     * @param authUserId
     * @return
     */
    ResponseJson updateAllAuthImage(Integer authUserId);

    /**
     * 更改联系人
     */
    ResponseJson changeLinkMan(Integer authUserId, String linkMan);

    /**
     * 更改logo
     */
    ResponseJson changeLogo(Integer authUserId, String logo);

    /**
     * 保存供应商品牌信息
     * @param authUserId
     * @param shopInfo
     * @return
     */
    ResponseJson saveShopInfo(Integer authUserId, ShopInfoDto shopInfo);

    /**
     * 删除供应商品牌信息
     */
    ResponseJson deleteShopInfo(Integer authUserId, Integer infoId);

    /**
     * 采美供应商列表
     * @return
     */
    ResponseJson<List<CmShopVo>> getCmShopList();
}
