package com.caimei.service.auth.impl;

import com.caimei.config.FastDfsClient;
import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.cmMapper.AuthProductMapper;
import com.caimei.mapper.cmMapper.ShopMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ProductSaveDto;
import com.caimei.model.po.ProductParamPo;
import com.caimei.model.po.ProductPo;
import com.caimei.model.po.ProductTypePo;
import com.caimei.model.vo.*;
import com.caimei.service.auth.AuthProductService;
import com.caimei.service.auth.UploadService;
import com.caimei.utils.Base64Util;
import com.caimei.utils.ImageUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import javax.swing.*;
import java.awt.*;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/17
 */
@Slf4j
@Service
public class AuthProductServiceImpl implements AuthProductService {

    @Resource
    private AuthProductMapper authProductMapper;

    @Resource
    private ShopMapper shopMapper;

    @Resource
    private AuthMapper authMapper;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    private UploadService uploadService;

    @Value("${spring.profiles.active}")
    private String active;

    @Value("${caimei.oldapi}")
    private String wwwServer;

    @Autowired
    private FastDfsClient client;

    @Autowired
    public void setUploadService(UploadService uploadService) {
        this.uploadService = uploadService;
    }

    @Override
    public ResponseJson<PageInfo<ProductListVo>> getProductList(Integer listType, Integer authId, String productName,
                                                                String snCode, Integer status, Integer auditStatus,
                                                                Integer shopAuditStatus, Integer pageNum, Integer pageSize) {
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权id", null);
        }
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<ProductListVo> productList = authProductMapper.getProductList(listType, authId, productName, snCode, status, auditStatus, shopAuditStatus);
        PageInfo<ProductListVo> pageData = new PageInfo<>(productList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson updateProductStatus(Integer productId, Integer status) {
        if (productId == null) {
            return ResponseJson.error("请输入用户id");
        }
        if (status == null) {
            return ResponseJson.error("请输入要更新的状态值");
        } else if (status != 0 && status != 1) {
            return ResponseJson.error("状态值只能为0或1");
        }
        authProductMapper.updateProductStatusByProductId(productId, status);
        if (status == 0) {
            return ResponseJson.success("下线授权商品成功");
        } else {
            return ResponseJson.success("上线授权商品成功");
        }
    }

    @Override
    public ResponseJson deleteProduct(Integer productId) {
        if (null == productId) {
            return ResponseJson.error("参数异常，请输入授权商品id");
        }
        // 删除商品
        authProductMapper.deleteProductByProductId(productId);
        // 删除商品参数
        authProductMapper.deleteParamsByProductId(productId);
        return ResponseJson.success("删除授权商品成功");
    }

    /**
     * 保存逻辑
     * relationId
     * null
     * 新设备:插入设备、插入关联信息
     * 关联设备：更新设备、插入关联信息
     * notNull
     * 数据库新设备
     * 新设备：更新设备、原设备无需更新关联关系
     * 关联设备：更新设备、更新关联信息（若原设备无机构关联，应删除该设备）
     * 数据库关联设备
     * 新设备：插入设备、更新关联信息
     * 关联设备：更新设备、更新关联信息
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseJson saveProduct(ProductSaveDto productSaveDto) throws IOException {
        Integer relationId = productSaveDto.getRelationId();
        Integer authType = productSaveDto.getAuthType();
        Integer authId = productSaveDto.getAuthId();
        Integer infoId = productSaveDto.getInfoId();
        Integer productTypeId = productSaveDto.getProductTypeId();
        String productName = productSaveDto.getProductName();
        String productImage = productSaveDto.getProductImage();
        String snCode = productSaveDto.getSnCode();
        String certificateImage = productSaveDto.getCertificateImage();
        Integer certificateImageType = productSaveDto.getCertificateImageType();
        Integer createBy = productSaveDto.getCreateBy();
        String purchaseWay = productSaveDto.getPurchaseWay();
        String invoiceImage = productSaveDto.getInvoiceImage();
        Integer source = null == productSaveDto.getSource() ? 1 : productSaveDto.getSource();
        List<String> snList=productSaveDto.getSnList();
        List<ProductParamPo> paramList = productSaveDto.getParamList();
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权id", null);
        }
        AuthVo auth = authMapper.getAuthById(authId);
        if (null == productTypeId) {
            // 新增设备分类，需要传入设备名称，品牌信息id，参数列表
            if (null == infoId) {
                return ResponseJson.error("参数异常，请输入品牌信息id", null);
            }
            if (StringUtils.isEmpty(productName)) {
                return ResponseJson.error("参数异常，请输入设备分类id或设备名称", null);
            }
            if (StringUtils.isNotEmpty(productName)) {
                ProductTypePo productType = authProductMapper.getProductType(null, productName, auth.getAuthUserId());
                if (null != productType) {
                    productTypeId = productType.getProductTypeId();
                }
            }
            if (null == paramList || paramList.size() <= 0) {
                return ResponseJson.error("参数异常，商品参数列表不能为空", null);
            }
        }
        if (StringUtils.isBlank(snCode)) {
            return ResponseJson.error("参数异常，请输入商品SN码", null);
        }
        if (1 == source) {
            if (2 == certificateImageType && StringUtils.isEmpty(certificateImage)) {
                return ResponseJson.error("授权牌不能为空");
            }
        } else {
            // 机构添加默认模板库生成
            certificateImageType = 1;
        }
        // 是否为添加操作
        boolean newRelation = null == relationId;
        ProductRelationVo dbRelation = null;
        ProductFormVo dbProduct = null;
        // 数据库设备id
        Integer dbProductId = null;
        // 当前设备id
        Integer productId = null;
        // 数据库中sn码对应设备id
        Integer productIdBySnCode = authProductMapper.getProductIdBySnCode(snCode);
        if (newRelation) {
            // 添加
            if (1 == authType) {
                // 新设备,设备id为null
                if (null != productIdBySnCode) {
                    return ResponseJson.error("该商品SN码已存在，请重新输入", null);
                }
            } else if (2 == authType){
                // 关联设备
                productId = productIdBySnCode;
                // 检测机构是否已关联该设备
                ProductRelationVo productRelation = authProductMapper.getProductRelation(null, productId, authId);
                if (null != productRelation) {
                    return ResponseJson.error("不能重复关联同一台设备");
                }
            }
        }else {
            // 编辑
            dbRelation = authProductMapper.getProductRelation(relationId, null, null);
            dbProduct = authProductMapper.getProductFormData(relationId);
            dbProductId = dbProduct.getProductId();
            if (1 == dbRelation.getAuthType()) {
                // 原本为新增设备
                if (1 == authType) {
                    // 设备id不变
                    productId = dbProductId;
                    if (null != productIdBySnCode && !productIdBySnCode.equals(productId)) {
                        return ResponseJson.error("该商品SN码已存在，请重新输入", null);
                    }
                } else if (2 == authType){
                    productId = productIdBySnCode;
                    // 检测机构是否已关联该设备
                    ProductRelationVo productRelation = authProductMapper.getProductRelation(null, productId, authId);
                    if (null != productRelation) {
                        return ResponseJson.error("不能重复关联同一台设备");
                    }
                }
            } else if (2 == dbRelation.getAuthType()){
                // 原本为关联设备
                if (1 == authType) {
                    // 设备id为null
                    if (null != productIdBySnCode) {
                        return ResponseJson.error("该商品SN码已存在，请重新输入", null);
                    }
                } else if (2 == authType) {
                    productId = productIdBySnCode;
                    // 检测机构是否已关联该设备
                    ProductRelationVo productRelation = authProductMapper.getProductRelation(null, productId, authId);
                    if (null != productRelation && !productRelation.getRelationId().equals(dbRelation.getRelationId())) {
                        return ResponseJson.error("不能重复关联同一台设备");
                    }
                }
            }
        }
        /*
            组装商品数据
         */
        ProductPo product = new ProductPo();
        // 设备id
        product.setProductId(productId);
        // 品牌信息id
        product.setInfoId(infoId);
        // 设备分类id
        product.setProductTypeId(productTypeId);
        if (null == productTypeId) {
            // 设备名称（仅机构添加新设备时使用）
            product.setName(productName);
            // 设备图片（仅机构添加新设备时使用）
            product.setImage(productImage);
        }
        // sn码
        product.setSnCode(snCode);
        // 授权牌照
        product.setCertificateImage(certificateImage);
        product.setCertificateImageType(certificateImageType);
        // 购买渠道
        product.setPurchaseWay(purchaseWay);
        // 发票图片
        product.setInvoiceImage(invoiceImage);
        // 供应商保存，直接上线；机构保存，需要供应商审核通过后才上线
        if (1 == authType) {
            product.setShopAuditStatus(1 == source ? 1 : 2);
            if (null != dbProduct && 1 != dbProduct.getAuditStatus()) {
                // 被驳回的数据，编辑变为待审核状态
                product.setStatus(2);
                product.setAuditStatus(2);
            } else {
                product.setStatus(1 == source ? 1 : 2);
                product.setAuditStatus(1 == source ? 1 : 2);
            }
        } else {
            product.setStatus(1);
            product.setAuditStatus(1);
            product.setShopAuditStatus(1);
        }
        Integer adminUserId = authMapper.getAdminUserId();
        product.setAuditBy(adminUserId);
        product.setAuditTime(new Date());
        product.setCheckFlag(0);
        // 创建人id
        product.setCreateBy(createBy);
        // 创建来源
        product.setCreateSource(source);
        // 创建时间
        product.setCreateTime(new Date());

        if (newRelation) {
            if (1 == authType) {
                // 插入授权商品
                authProductMapper.insertProduct(product);
            } else {
                // 关联设备，更新设备
                authProductMapper.updateProductByProductId(product);
            }
            // 插入机构设备关联关系
            relationId = authProductMapper.insertProductRelation(authId, product.getProductId(), authType);
        } else {
            if (1 == dbRelation.getAuthType()) {
                // 更新设备
                authProductMapper.updateProductByProductId(product);
                if (2 == authType) {
                    // 更新机构设备关联关系
                    authProductMapper.updateProductRelation(dbRelation.getRelationId(), authId, product.getProductId(), authType);
                    // 原本关联的新增设备若无关联机构，删除该设备
                    Integer relationCount = authProductMapper.getProductRelationCount(dbProduct.getProductId());
                    if (relationCount <= 0) {
                        authProductMapper.deleteProductByProductId(dbProduct.getProductId());
                    }
                }
            } else {
                if (1 == authType) {
                    // 插入授权商品
                    authProductMapper.insertProduct(product);
                } else {
                    // 更新设备
                    authProductMapper.updateProductByProductId(product);
                    //1.7.4改为
                }
                // 更新机构设备关联关系
                authProductMapper.updateProductRelation(dbRelation.getRelationId(), authId, product.getProductId(), authType);
            }
        }
        ProductFormVo newDbProduct = authProductMapper.getProductFormData(relationId);
        // 保存之后生成授权牌和水印授权牌
        if (1 == product.getCertificateImageType()) {
            // 模板库生成
            // 获取对应模板
            TemplateVo authTemplate = authMapper.getAuthTemplate(authId, null, 2);
            certificateImage = generateAuthImage(authTemplate, newDbProduct);
            product.setCertificateImage(certificateImage);
        }
        // 添加水印
        if (StringUtils.isNotEmpty(product.getCertificateImage())) {
            product.setPcCertificateImage(addWaterMark(product.getCertificateImage(), 1));
            product.setAppletsCertificateImage(addWaterMark(product.getCertificateImage(), 2));
            authProductMapper.updateCertificateImage(product);
        }
        // 删除商品参数
        authProductMapper.deleteParamsByProductId(product.getProductId());
        // 保存商品参数
        if (null == productTypeId) {
            paramList.forEach(param -> {
                if (StringUtils.isNotBlank(param.getParamName()) && StringUtils.isNotBlank(param.getParamContent())) {
                    authProductMapper.insertProductParam(product.getProductId(), param.getParamName(), param.getParamContent());
                }
            });
        }
        return ResponseJson.success("保存授权商品成功");
    }
    @Override
    @Transactional(rollbackFor = Exception.class)
    public  ResponseJson saveProductAndRelaTion(Integer authId,List<String> snlist,Integer authType) throws IOException{
        //判断机构关联id是否有值（有则机构关联关联了其他机构属于新增操作，无则属于编辑操作）
        String relaId = authProductMapper.getRelationId(authId);
        List<Integer>  listSnId=new ArrayList<>();
        if(null!=relaId&&!"".equals(relaId)){
            //根据sn码获取产品id
            for(int i=0;i<snlist.size();i++){
                List<ProductPo> List = authProductMapper.getSnList(snlist.get(i));
                //判断本身机构下的设备和关联机构下 设备有不有重复的
                if(List.get(0).getAuthId()!=authId){
                    listSnId.add(List.get(0).getProductId());
                }
            }
            //根据产品id插入机构设备关联关系
            for(int i=0;i<snlist.size();i++){
                authProductMapper.insertProductRelation(authId, listSnId.get(i), authType);
            }
            return ResponseJson.success("保存授权商品成功");
        }else{
            //根据sn码获取产品id
            for(int i=0;i<snlist.size();i++){
                List<ProductPo> List = authProductMapper.getSnList(snlist.get(i));
                //判断本身机构下的设备和关联机构下 设备有不有重复的
                if(List.get(0).getAuthId()!=authId){
                    listSnId.add(List.get(0).getProductId());
                }
            }
            //根据产品id插入机构设备关联关系
            for(int i=0;i<snlist.size();i++){
                authProductMapper.insertProductRelation(authId, listSnId.get(i), authType);
            }
            return ResponseJson.success("保存授权商品成功");
        }
    }

    public String generateAuthImage(TemplateVo authTemplate, ProductFormVo product) {
        if (null != authTemplate) {
            // 根据模板id设置相关数据
            Map<String, Object> templateInfo = getTemplateInfo(authTemplate, product);
            Object templateImage = templateInfo.get("templateImage");
            if (null != templateImage) {
                String authImage = ImageUtils.generateAuthImage(templateInfo);
                log.info("【图片上传】>>>>>>>>>>>>>>>>图片临时路径:" + authImage);
                // 临时图片
                File tempFile = new File(authImage);
                String imageUrl = null;
                try {
                    imageUrl = imageDomain + "/" + client.uploadFile(authImage);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                // 删除临时图片
                boolean delete = tempFile.delete();
                log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时图片:" + delete);
                return imageUrl;
            } else {
                return null;
            }
        }
        return null;
    }

    private Map<String,Object> getTemplateInfo(TemplateVo template, ProductFormVo product) {
        HashMap<String, Object> map = new HashMap<>();
        Integer templateId = template.getTemplateId();
        if (1 == templateId) {
            map.put("templateImage", template.getTemplateImage());
            double rate = 0.15;
            String productName = product.getProductName();
            if (StringUtils.isNotEmpty(productName)) {
                map.put("addWord1_content", productName);
                map.put("addWord1_color", "0,0,0");
                map.put("addWord1_type", "思源宋体");
                map.put("addWord1_style", Font.BOLD);
                map.put("addWord1_size", (int) Math.round(233 * rate));
                // 获取设备名字位置
                try {
                    ImageIcon imageIcon = new ImageIcon(new URL(template.getTemplateImage()));
                    Image srcImg = imageIcon.getImage();
                    int srcWidth = srcImg.getWidth(null);
                    int wordWidth = ImageUtils.getWordWidth(new Font("思源宋体", Font.BOLD, (int) Math.round(233 * rate)), productName);
                    int x = (srcWidth - (int) Math.round(238 * rate) - wordWidth) / 2 + (int) Math.round(238 * rate);
                    int y = (int) Math.round(1630 * rate);
                    // 居中
                    map.put("addWord1_x", x);
                    map.put("addWord1_y", y);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
            // 添加认证编号信息
            if (StringUtils.isNotEmpty(product.getSnCode())) {
                map.put("addWord2_content", product.getSnCode());
                map.put("addWord2_color", "218,185,107");
                map.put("addWord2_type", "思源宋体");
                map.put("addWord2_style", Font.BOLD);
                map.put("addWord2_size", (int) Math.round(90 * rate));
                map.put("addWord2_x", (int) Math.round(2168 * rate));
                map.put("addWord2_y", (int) Math.round(3160 * rate));
            }
            // 添加认证日期信息
            if (null != product.getCreateTime()) {
                SimpleDateFormat format = new SimpleDateFormat("yyyy.MM.dd");
                map.put("addWord3_content", format.format(product.getCreateTime()));
                map.put("addWord3_color", "218,185,107");
                map.put("addWord3_type", "思源宋体");
                map.put("addWord3_style", Font.PLAIN);
                map.put("addWord3_size", (int) Math.round(90 * rate));
                map.put("addWord3_x", (int) Math.round(2085 * rate));
                map.put("addWord3_y", (int) Math.round(3292 * rate));
            }
            // 添加二维码信息
            if (StringUtils.isNotEmpty(template.getQrPosition())) {
                String qrCodeLink = wwwServer + "/product/auth/product-" + product.getProductId() + ".html";
                map.put("addQr1_link", qrCodeLink);
                map.put("addQr1_size", template.getQrSize());
                String[] split = template.getQrPosition().split(",");
                if (split.length == 2) {
                    map.put("addQr1_x", Integer.parseInt(split[0]));
                    map.put("addQr1_y", Integer.parseInt(split[1]));
                }
            }
        }
        return map;
    }

    private String addWaterMark(String image,Integer type) throws IOException {
        //type:1pc,2applets
        ClassPathResource classPathResource = new ClassPathResource("/images/newPcWaterMark.png");
        InputStream inputStreamImg = classPathResource.getInputStream();
        Image pcWaterMarkImg = ImageIO.read(inputStreamImg);
        classPathResource = new ClassPathResource("/images/newAppletsWaterMark.png");
        inputStreamImg = classPathResource.getInputStream();
        Image appletsWaterMarkImg = ImageIO.read(inputStreamImg);
        String img = ImageUtils.markImageByIcon(type == 1 ? pcWaterMarkImg : appletsWaterMarkImg, image, null);
        String imagePath = null;
        if (StringUtils.isNotEmpty(img)) {
            MultipartFile imgFile = Base64Util.base64ToMultipart(img);
            if (null != imgFile) {
                imagePath = uploadService.saveFile(imgFile);
            }
            log.info(">>>>>>>>>>>>>>>>水印图片上传成功:" + imagePath);
        } else {
            log.info(">>>>>>>>>>>>>>>>水印图片上传失败");
        }
        return imagePath;
    }

    /*private String addQrCode(String certificateImage, Integer productId, Integer addTemplateType) throws IOException {
        String qrCodeLink = wwwServer + "/product/auth/product-" + productId + ".html";
        String qrCodeImage = ImageUtils.addQrCode(certificateImage, qrCodeLink, addTemplateType);
        String imagePath = null;
        if (StringUtils.isNotEmpty(qrCodeImage)) {
            MultipartFile imgFile = Base64Util.base64ToMultipart(qrCodeImage);
            if (null != imgFile) {
                imagePath = uploadService.saveFile(imgFile);
            }
            log.info(">>>>>>>>>>>>>>>>二维码图片上传成功:" + imagePath);
        } else {
            log.info(">>>>>>>>>>>>>>>>二维码图片上传失败");
        }
        return imagePath;
    }*/

    @Override
    public ResponseJson<ProductFormVo> getProductFormData(Integer relationId) {
        ProductFormVo productForm = authProductMapper.getProductFormData(relationId);
        if (null == productForm) {
            return ResponseJson.error("设备不存在", null);
        }
        List<ProductParamPo> paramList = authProductMapper.getProductTypeParamList(productForm.getProductTypeId());
        if (null == paramList || paramList.size() == 0) {
            paramList = authProductMapper.getParamsByProductId(productForm.getProductId());
        }
        productForm.setParamList(paramList);
        return ResponseJson.success(productForm);
    }

    @Override
    public List<Integer> getProductIdsByAuthId(Integer authId) {
        return authProductMapper.getProductIdsByAuthId(authId);
    }

    @Override
    public ResponseJson updateAllWaterMark() {
        List<ProductPo> productList = authProductMapper.getAllImage();
        productList.forEach(product->{
            try {
                if (StringUtils.isNotEmpty(product.getImage())) {
                    //商品图片添加水印
                    product.setPcImage(addWaterMark(product.getImage(), 1));
                    product.setAppletsImage(addWaterMark(product.getImage(), 2));
                }
                if (StringUtils.isNotEmpty(product.getCertificateImage())) {
                    //授权牌照添加水印
                    product.setPcCertificateImage(addWaterMark(product.getCertificateImage(), 1));
                    product.setAppletsCertificateImage(addWaterMark(product.getCertificateImage(), 2));
                }
                // 更新授权商品
                authProductMapper.updateImageByProductId(product);
            } catch (IOException e) {
                e.printStackTrace();
            }
        });
        return ResponseJson.success("更新商品水印图片成功");
    }

    @Override
    public ResponseJson auditProduct(Integer productId, Integer auditStatus, String invalidReason, Integer auditBy, Integer source) {
        if (productId == null) {
            return ResponseJson.error("请输入商品id");
        }
        if (auditStatus == null) {
            return ResponseJson.error("请输入审核结果");
        }
        if (auditStatus == 0 && StringUtils.isEmpty(invalidReason)) {
            return ResponseJson.error("请输入审核不通过的原因");
        }
        if (auditBy == null) {
            return ResponseJson.error("请输入审核人用户id");
        }
        source = null == source ? 1 : source;
        Date auditTime = new Date();
        int status = 0;
        if (1 == auditStatus) {
            status = 1;
        }
        if (1 == source) {
            // 获取设备信息
            ProductPo product = authProductMapper.getProductPo(productId);
            Integer productTypeId = product.getProductTypeId();
            if (1 == auditStatus && null == productTypeId && StringUtils.isNotEmpty(product.getName()) && StringUtils.isNotEmpty(product.getImage())) {
                // 新增设备分类
                Integer authUserId = authProductMapper.getAuthUserIdByProductId(productId);
                // 查询设备分类是否已存在
                ProductTypePo productType = authProductMapper.getProductType(null, product.getName(), authUserId);
                if (null == productType) {
                    List<ProductParamPo> paramList = authProductMapper.getParamsByProductId(productId);
                    try {
                        ResponseJson<ProductTypePo> result = saveProductType(null, authUserId, product.getInfoId(), product.getName(), product.getImage(), product.getCreateBy(), paramList, 2);
                        int code = result.getCode();
                        if (0 == code) {
                            productType = result.getData();
                            productTypeId = productType.getProductTypeId();
                            // 设备分类直接审核通过
                            auditProductType(productTypeId, 1, null, auditBy);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                } else {
                    productTypeId = productType.getProductTypeId();
                }
            }
            authProductMapper.updateProductAuditStatus(productId, productTypeId, status, auditStatus, invalidReason, auditBy, auditTime);
        }
        if (2 == source) {
            // 获取设备信息
            ProductPo product = authProductMapper.getProductPo(productId);
            Integer productTypeId = product.getProductTypeId();
            if (1 == auditStatus && null == productTypeId && StringUtils.isNotEmpty(product.getName()) && StringUtils.isNotEmpty(product.getImage())) {
                // 新增设备分类
                Integer authUserId = authProductMapper.getAuthUserIdByProductId(productId);
                // 查询设备分类是否已存在
                ProductTypePo productType = authProductMapper.getProductType(null, product.getName(), authUserId);
                if (null == productType) {
                    List<ProductParamPo> paramList = authProductMapper.getParamsByProductId(productId);
                    try {
                        ResponseJson<ProductTypePo> result = saveProductType(null, authUserId, product.getInfoId(), product.getName(), product.getImage(), product.getCreateBy(), paramList, 2);
                        int code = result.getCode();
                        if (0 == code) {
                            productType = result.getData();
                            productTypeId = productType.getProductTypeId();
                            // 设备分类直接审核通过
                            auditProductType(productTypeId, 1, null, auditBy);
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                } else {
                    productTypeId = productType.getProductTypeId();
                }
            }
            authProductMapper.updateProductShopAuditStatus(productId, productTypeId, status, auditStatus, invalidReason, auditBy, auditTime);
        }
        return ResponseJson.success("审核商品成功");
    }

    @Override
    public ResponseJson<PageInfo<WxProductListVo>> getWxProductList(Integer listType, Integer authId, String authParty, Integer productTypeId, String snCode, Integer pageNum, Integer pageSize) {
        listType = null == listType ? 1 : listType;
        if (1 == listType) {
            if (null == productTypeId) {
                return ResponseJson.error("参数异常，请输入设备分类id", null);
            } else if (StringUtils.isEmpty(snCode) && StringUtils.isEmpty(authParty)) {
                return ResponseJson.error("搜索条件不能为空", null);
            }
        }
        PageHelper.startPage(pageNum, pageSize);
        List<WxProductListVo> productList = authProductMapper.getWxProductList(listType, authId, authParty, productTypeId, snCode);
        productList.forEach(product->{
            List<WxClubListVo> clubList = authProductMapper.getProductClubList(product.getProductId());
            product.setClubList(clubList);
        });
        PageInfo<WxProductListVo> pageData = new PageInfo<>(productList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<AuthProductVo> getAuthProductDetails(Integer productId) {
        AuthProductVo authProduct = authProductMapper.getAuthProductByProductId(productId);
        if (null == authProduct) {
            return ResponseJson.error("商品不存在", null);
        }
        authProduct.setClubList(authProductMapper.getProductClubList(productId));
        // 商品参数
        authProduct.setParamList(authProductMapper.getAuthProductParams(productId));
        // 增加扫码次数
        authProductMapper.addScanCount(productId);
        return ResponseJson.success(authProduct);
    }

    @Override
    public ResponseJson<ProductTypePo> saveProductType(Integer productTypeId, Integer authUserId, Integer infoId, String name, String image, Integer createBy, List<ProductParamPo> paramList, Integer createSource) throws IOException {
        // 是否为添加操作
        boolean insertFlag = null == productTypeId;
        ProductTypePo dbProductType = null;
        if (!insertFlag) {
            dbProductType = authProductMapper.getProductType(productTypeId, null, null);
        }
        /*
         * 组装设备分类数据
         */
        ProductTypePo productType = new ProductTypePo();
        productType.setAuthUserId(authUserId);
        productType.setInfoId(infoId);
        productType.setName(name);
        productType.setImage(image);
        productType.setCreateBy(createBy);
        productType.setCreateTime(new Date());
        // 上线状态默认为“待上线”，审核状态为“待审核”
        /*productType.setStatus(2);
        productType.setAuditStatus(2);*/
        // 供应商保存，直接上线；机构保存，需要供应商审核通过后才上线
        if (null != dbProductType && 1 != dbProductType.getAuditStatus()) {
            // 被驳回的数据，编辑变为待审核状态
            productType.setStatus(2);
            productType.setAuditStatus(2);
        } else {
            productType.setStatus(1 == createSource ? 1 : 2);
            productType.setAuditStatus(1 == createSource ? 1 : 2);
        }
        Integer adminUserId = authMapper.getAdminUserId();
        productType.setAuditBy(adminUserId);
        productType.setAuditTime(new Date());
        productType.setCreateSource(createSource);
        productType.setCheckFlag(0);
        if (insertFlag) {
            // 创建人id
            productType.setCreateBy(createBy);
            // 创建时间
            productType.setCreateTime(new Date());
            // 设备分类图片添加水印
            productType.setPcImage(addWaterMark(productType.getImage(),1));
            productType.setAppletsImage(addWaterMark(productType.getImage(),2));
            // 插入设备分类
            authProductMapper.insertProductType(productType);
        } else {
            // 设备分类id
            productType.setProductTypeId(productTypeId);
            // 设备分类图片是否重新上传
            boolean updateImageFlag = (StringUtils.isNotBlank(productType.getImage()) && !productType.getImage().equals(dbProductType.getImage()))
                    || (StringUtils.isEmpty(productType.getPcImage()) || StringUtils.isEmpty(productType.getAppletsImage()));
            if (updateImageFlag) {
                //商品图片添加水印
                productType.setPcImage(addWaterMark(productType.getImage(), 1));
                productType.setAppletsImage(addWaterMark(productType.getImage(), 2));
            }
            // 更新设备分类
            authProductMapper.updateProductType(productType);
        }
        // 删除设备分类参数
        authProductMapper.deleteParamsByProductTypeId(productType.getProductTypeId());
        // 保存商品参数
        if (null != paramList) {
            paramList.forEach(param -> {
                if (StringUtils.isNotBlank(param.getParamName()) && StringUtils.isNotBlank(param.getParamContent())) {
                    authProductMapper.insertProductTypeParam(productType.getProductTypeId(), param.getParamName(), param.getParamContent());
                }
            });
        }
        return ResponseJson.success("保存设备分类成功", productType);
    }

    @Override
    public ResponseJson deleteProductType(Integer productTypeId) {
        Integer count = authProductMapper.getProductCountByTypeId(productTypeId);
        if (count > 0) {
            return ResponseJson.error("该设备有绑定设备认证，暂时无法删除");
        }
        authProductMapper.deleteProductType(productTypeId);
        authProductMapper.deleteParamsByProductTypeId(productTypeId);
        return ResponseJson.success("删除设备分类成功");
    }

    @Override
    public ResponseJson updateProductTypeStatus(Integer productTypeId, Integer status) {
        authProductMapper.updateProductTypeStatus(productTypeId, status);
        if (status == 0) {
            return ResponseJson.success("下线设备分类成功");
        } else {
            return ResponseJson.success("上线设备分类成功");
        }
    }

    @Override
    public ResponseJson<PageInfo<ProductTypeListVo>> getProductTypeList(Integer listType, Integer authUserId, String name, Integer status, Integer auditStatus, Integer pageNum, Integer pageSize) {
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<ProductTypeListVo> productList = authProductMapper.getProductTypeList(listType, authUserId, name, status, auditStatus);
        PageInfo<ProductTypeListVo> pageData = new PageInfo<>(productList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<List<ProductTypeListVo>> getProductTypeSelectList(Integer authUserId) {
        List<ProductTypeListVo> productTypeList = authProductMapper.getProductTypeList(null, authUserId, null, 1, 1);
        return ResponseJson.success(productTypeList);
    }

    @Override
    public ResponseJson auditProductType(Integer productTypeId, Integer auditStatus, String invalidReason, Integer auditBy) {
        Date auditTime = new Date();
        int status = 0;
        if (1 == auditStatus) {
            status = 1;
        }
        authProductMapper.updateProductTypeAuditStatus(productTypeId, status, auditStatus, invalidReason, auditBy, auditTime);
        return ResponseJson.success("审核设备分类成功");
    }

    @Override
    public ResponseJson<PageInfo<WxProductTypeListVo>> getWxProductTypeList(Integer authUserId, String appId, String name, Integer pageNum, Integer pageSize) {
        if (null == authUserId && StringUtils.isNotEmpty(appId)) {
            authUserId = shopMapper.getUserIdByAppId(appId);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<WxProductTypeListVo> productTypeList = authProductMapper.getWxProductTypeList(authUserId, name);
        PageInfo<WxProductTypeListVo> pageData = new PageInfo<>(productTypeList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<ProductTypePo> getProductTypeFromData(Integer productTypeId) {
        ProductTypePo productType = authProductMapper.getProductType(productTypeId, null, null);
        List<ProductParamPo> paramList = authProductMapper.getProductTypeParamList(productTypeId);
        productType.setParamList(paramList);
        return ResponseJson.success(productType);
    }

    @Override
    public ResponseJson checkAuthProduct(Integer productId) {
        authProductMapper.checkAuthProduct(productId);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<ProductFormVo> getProductInfo(Integer productId, String snCode) {
        ProductFormVo product =  authProductMapper.getProductInfo(productId, snCode);
        if (null == product) {
            return ResponseJson.error(-1, "设备SN码不存在", null);
        }
        if (2 == product.getAuditStatus()) {
            return ResponseJson.error(-2, "设备待审核", null);
        }
        if (0 == product.getAuditStatus()) {
            return ResponseJson.error(-3, "设备审核失败", null);
        }
        return ResponseJson.success(product);
    }

    @Override
    public ResponseJson<List<String>> getSnCodeList(Integer authUserId, Integer authId) {
        //获取该机构下所有的sn码
        List<Integer> liallSn = authProductMapper.getAllSn(authId);
        List<String> allSnlist = authProductMapper.getAllSnlist(liallSn);
        List<String> snCodeList = authProductMapper.getSnCodeList(authUserId, authId,allSnlist);
        return ResponseJson.success(snCodeList);
    }

    @Override
    public ResponseJson<List<String>> getSnCodeList1(Integer authUserId, Integer authId) {
        //判断该机构是否与其他机构关联
        String relationId = authProductMapper.getRelationId(authId);
        String[] relationIdList=null;
        List<String> snCodeList=new ArrayList<>();
        if (!"".equals(relationId)&&null !=relationId){
            relationIdList = relationId.split(",");
            //获取该机构下所有的sn码
            List<Integer> liallSn = authProductMapper.getAllSn(authId);
            List<String> allSnlist = authProductMapper.getAllSnlist(liallSn);
            snCodeList = authProductMapper.getSnCodeList1(authUserId, authId,relationIdList,allSnlist);
        }
        return ResponseJson.success(snCodeList);

    }

    @Override
    public ResponseJson checkProductType(Integer productTypeId) {
        authProductMapper.checkProductType(productTypeId);
        return ResponseJson.success();
    }

    public ResponseJson<List<ProductListVo>> getPronductInfo( Integer authId,Integer authUserId){
        List<ProductListVo> pronductInfo = authProductMapper.getPronductInfo(authId, authUserId);
        return ResponseJson.success(pronductInfo);
    }

}
