package com.caimei.service.auth.impl;

import com.caimei.mapper.cmMapper.AuthTemplateMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.vo.*;
import com.caimei.service.auth.AuthTemplateService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.net.URL;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2022/7/6
 */
@Slf4j
@Service
public class AuthTemplateServiceImpl implements AuthTemplateService {

    @Resource
    private AuthTemplateMapper authTemplateMapper;

    @Override
    public ResponseJson<PageInfo<TemplateVo>> getTemplateList(Integer listType, Integer authUserId, Integer pageNum, Integer pageSize) {
        if (null == listType) {
            return ResponseJson.error("列表类型不能为空", null);
        }
        if (2 == listType && null == authUserId) {
            return ResponseJson.error("供应商用户id不能为空", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<TemplateVo> templateList = authTemplateMapper.getTemplateList(listType, authUserId);
        PageInfo<TemplateVo> pageInfo = new PageInfo<>(templateList);
        return ResponseJson.success(pageInfo);
    }

    @Override
    public ResponseJson saveTemplate(Integer templateId, String templateImage, Integer authUserId, Integer status, String qrPosition, Integer qrSize, String logoSize, Integer authFlag, Integer productFlag) {
        boolean insertFlag = null == templateId;
        Integer width = null;
        Integer height = null;
        String templateSize = null;
        if (StringUtils.isNotEmpty(templateImage)) {
            try {
                BufferedImage image = ImageIO.read(new URL(templateImage));
                width = image.getWidth();
                height = image.getHeight();
            } catch (Exception e) {
                e.printStackTrace();
            }
            templateSize = (null == width ? 0 : width) + "," + (null == height ? 0 : height);
        }
        if (insertFlag) {
            if (StringUtils.isEmpty(qrPosition)) {
                // 默认左上角
                qrPosition = "0,0";
            }
            authTemplateMapper.insertTemplate(templateImage, authUserId, templateSize, qrPosition, qrSize, logoSize);
        } else {
            TemplateVo dbTemplate = authTemplateMapper.getTemplateFormData(templateId, null, null, null, null);
            if (null != authFlag && 1 == authFlag) {
                authTemplateMapper.clearAuthFlag(authUserId);
            }
            if (null != productFlag && 1 == productFlag) {
                authTemplateMapper.clearProductFlag(authUserId);
            }
            if (null != dbTemplate) {
                if (null != authUserId && !dbTemplate.getAuthUserId().equals(authUserId)) {
                    // 更新了供应商,不选中位置
                    authFlag = 0;
                    productFlag = 0;
                }
                authTemplateMapper.updateSelective(templateId, templateImage, templateSize, authUserId, status, qrPosition, qrSize, logoSize, authFlag, productFlag);
            }
        }
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<TemplateVo> getTemplateFormData(Integer templateId, Integer authId, Integer authUserId, Integer authFlag, Integer status) {
        TemplateVo templateVo = authTemplateMapper.getTemplateFormData(templateId, authId, authUserId, authFlag, status);
        return ResponseJson.success(templateVo);
    }

}
