package com.caimei.service.auth.impl;

import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.cmMapper.DoctorMapper;
import com.caimei.mapper.cmMapper.ShopMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.CmBrandDoctorPo;
import com.caimei.model.vo.*;
import com.caimei.service.auth.DoctorService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2022/1/7
 */
@Slf4j
@Service
public class DoctorServiceImpl implements DoctorService {

    @Resource
    private AuthMapper authMapper;

    @Resource
    private DoctorMapper doctorMapper;

    @Resource
    private ShopMapper shopMapper;

    @Value("${spring.profiles.active}")
    private String active;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    @Override
    public ResponseJson<PageInfo<DoctorListVo>> getDoctorList(Integer listType, Integer authUserId, Integer doctorType, String doctorName, String certificateNo, Integer status, Integer auditStatus, Integer pageNum, Integer pageSize) {
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<DoctorListVo> doctorList = doctorMapper.getDoctorList(listType, authUserId, doctorType, doctorName, certificateNo, status, auditStatus);
        PageInfo<DoctorListVo> pageData = new PageInfo<>(doctorList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson updateDoctorStatus(Integer doctorId, Integer status) {
        if (null == doctorId) {
            return ResponseJson.error("请输入医师id");
        }
        if (null == status) {
            return ResponseJson.error("请输入要更新的状态值");
        }
        doctorMapper.updateDoctorStatus(doctorId, status);
        if (0 == status) {
            return ResponseJson.success("下线医师成功");
        } else {
            return ResponseJson.success("上线医师成功");
        }
    }

    @Override
    public ResponseJson deleteDoctor(Integer doctorId) {
        if (null == doctorId) {
            return ResponseJson.error("参数异常，请输入医师id");
        }
        // 删除医师
        doctorMapper.deleteDoctorByDoctorId(doctorId);
        // 删除轮播图
        doctorMapper.deleteBanner(doctorId);
        // 删除仪器
        doctorMapper.deleteEquipment(doctorId);
        // 删除标签
        doctorMapper.deleteTag(doctorId);
        // 删除属性
        doctorMapper.deleteParam(doctorId);
        return ResponseJson.success("删除医师成功");
    }

    @Override
    public ResponseJson<DoctorFormVo> getDoctorFormData(Integer doctorId) {
        if (null == doctorId) {
            return ResponseJson.error("参数异常,医师id不能为空", null);
        }
        CmBrandDoctorPo doctor = doctorMapper.getDoctorById(doctorId);
        DoctorFormVo doctorFormVo = new DoctorFormVo();
        doctorFormVo.setDoctorId(doctor.getId());
        doctorFormVo.setDoctorName(doctor.getName());
        doctorFormVo.setDoctorImage(doctor.getImage());
        BeanUtils.copyProperties(doctor, doctorFormVo);
        // 轮播图
        List<String> bannerList = doctorMapper.getBannerList(doctorId);
        doctorFormVo.setBannerList(bannerList);
        // 仪器
        List<DoctorEquipmentVo> equipmentList = doctorMapper.getEquipmentList(doctorId);
        doctorFormVo.setEquipmentList(equipmentList);
        // 标签
        List<String> tagList = doctorMapper.getTagList(doctorId);
        doctorFormVo.setTagList(tagList);
        // 属性
        List<ParamVo> paramList = doctorMapper.getParamList(doctorId);
        doctorFormVo.setParamList(paramList);
        return ResponseJson.success(doctorFormVo);
    }

    @Override
    public ResponseJson saveDoctor(CmBrandDoctorPo doctor, List<String> bannerList, List<Map<String, Object>> equipmentList, List<String> tagList, List<Map<String, String>> paramList) {
        Integer doctorId = doctor.getId();
        Integer authUserId = doctor.getAuthUserId();
        String certificateNo = doctor.getCertificateNo();
        if (StringUtils.isBlank(doctor.getName())) {
            return ResponseJson.error("参数异常，请输入医师名称");
        }
        if (StringUtils.isBlank(certificateNo)) {
            return ResponseJson.error("参数异常，请输入从业资格证编号");
        }
        Integer doctorIdByCertificateNo = doctorMapper.getDoctorIdByCertificateNo(certificateNo, authUserId);
        if (null != doctorIdByCertificateNo && !doctorIdByCertificateNo.equals(doctorId)) {
            return ResponseJson.error("参数异常，该从业资格证编号已存在，请重新输入", null);
        }
        if (StringUtils.isEmpty(doctor.getClubName()) && (null == doctor.getAuthId() || -1 == doctor.getAuthId())) {
            return ResponseJson.error("参数异常，请输入所属机构");
        }
        if (null == doctor.getAuthId() || -1 == doctor.getAuthId()) {
            doctor.setAuthId(null);
        } else{
            doctor.setClubName(null);
        }
        if (null == doctor.getDoctorType()) {
            return ResponseJson.error("参数异常，请输入医师类型");
        }
        if (StringUtils.isBlank(doctor.getImage())) {
            return ResponseJson.error("参数异常，请上传医师照片");
        }
        if (null == doctor.getCreateBy()) {
            return ResponseJson.error("参数异常，请输入创建人id");
        }
        if (null == bannerList || bannerList.size() <= 0) {
            return ResponseJson.error("参数异常，请上传轮播图");
        }
        if (1 == doctor.getDoctorType() && (null == equipmentList || equipmentList.size() <= 0)) {
            return ResponseJson.error("参数异常，请上传设备列表");
        }
        boolean insertFlag = null == doctorId;
        CmBrandDoctorPo dbDoctor = null;
        if (!insertFlag) {
            dbDoctor = doctorMapper.getDoctorById(doctorId);
        }
        // 供应商保存，直接上线；机构保存，需要供应商审核通过后才上线
        if (null != dbDoctor && 1 != dbDoctor.getAuditStatus()) {
            // 被驳回的数据，编辑变为待审核状态
            doctor.setStatus(2);
            doctor.setAuditStatus(2);
        } else {
            doctor.setStatus(1);
            doctor.setAuditStatus(1);
        }
        Integer adminUserId = authMapper.getAdminUserId();
        doctor.setAuditBy(adminUserId);
        doctor.setAuditTime(new Date());
        doctor.setCheckFlag(0);
        /*
            保存医师
         */
        if (null == doctorId) {
            doctorMapper.insertDoctor(doctor);
        } else {
            doctorMapper.updateDoctorByDoctorId(doctor);
            // 删除原有的轮播图
            doctorMapper.deleteBanner(doctor.getId());
            // 删除原有的设备
            doctorMapper.deleteEquipment(doctor.getId());
            // 删除原有的标签
            doctorMapper.deleteTag(doctor.getId());
            // 删除原有的属性
            doctorMapper.deleteParam(doctor.getId());
        }
        // 保存轮播图
        bannerList.forEach(banner-> doctorMapper.insertBanner(doctor.getId(), banner));
        // 保存设备
        equipmentList.forEach(equipment-> doctorMapper.insertEquipment(doctor.getId(), (String) equipment.get("equipmentName"), (String) equipment.get("brand"), (String) equipment.get("image")));
        // 保存标签
        tagList.forEach(tag -> doctorMapper.insertTag(doctor.getId(), tag));
        // 保存属性
        paramList.forEach(param -> doctorMapper.insertParam(doctor.getId(), param.get("name"), param.get("content")));
        return ResponseJson.success("保存医师成功", doctor);
    }

    @Override
    public ResponseJson auditDoctor(Integer doctorId, Integer auditStatus, String invalidReason, Integer auditBy) {
        if (doctorId == null) {
            return ResponseJson.error("请输入医师id");
        }
        if (auditStatus == null) {
            return ResponseJson.error("请输入审核结果");
        }
        if (auditStatus == 0 && StringUtils.isEmpty(invalidReason)) {
            return ResponseJson.error("请输入审核不通过的原因");
        }
        Date auditTime = new Date();
        // 医师状态更新
        Integer status = null;
        if (auditStatus == 0) {
            // 审核不通过，下线医师
            status = 0;
        } else {
            // 审核通过，上线医师
            status = 1;
        }
        doctorMapper.updateDoctorAuditStatus(doctorId, status, auditStatus, invalidReason, auditBy, auditTime);
        return ResponseJson.success("审核医师成功");
    }

    @Override
    public ResponseJson<PageInfo<WxDoctorListVo>> getWxDoctorList(Integer authUserId, String appId, Integer doctorType, String doctorName, Integer pageNum, Integer pageSize) {
        if (null == authUserId && StringUtils.isNotEmpty(appId)) {
            authUserId = shopMapper.getUserIdByAppId(appId);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<WxDoctorListVo> doctorList = doctorMapper.getWxDoctorList(authUserId, null, doctorType, doctorName);
        doctorList.forEach(doctor -> {
            List<String> tagList = doctorMapper.getTagList(doctor.getDoctorId());
            doctor.setTagList(tagList);
        });
        PageInfo<WxDoctorListVo> pageData = new PageInfo<>(doctorList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<DoctorFormVo> getAuthDoctorDetails(Integer doctorId) {
        if (null == doctorId) {
            return ResponseJson.error("参数异常,医师id不能为空", null);
        }
        DoctorFormVo doctor = doctorMapper.getDoctorDetailsById(doctorId);
        if (null == doctor) {
            return ResponseJson.error("医师不存在", null);
        }
        // 轮播图
        List<String> bannerList = doctorMapper.getBannerList(doctorId);
        doctor.setBannerList(bannerList);
        // 仪器
        List<DoctorEquipmentVo> equipmentList = doctorMapper.getEquipmentList(doctorId);
        doctor.setEquipmentList(equipmentList);
        // 标签
        List<String> tagList = doctorMapper.getTagList(doctorId);
        doctor.setTagList(tagList);
        // 属性
        List<ParamVo> paramList = doctorMapper.getParamList(doctorId);
        doctor.setParamList(paramList);
        return ResponseJson.success(doctor);
    }

    @Override
    public ResponseJson checkDoctor(Integer doctorId) {
        doctorMapper.checkDoctor(doctorId);
        return ResponseJson.success();
    }
}
