package com.caimei.service.auth.impl;

import com.alibaba.fastjson.JSONArray;
import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.cmMapper.LogisticsMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.*;
import com.caimei.model.vo.*;
import com.caimei.service.auth.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Slf4j
@Service
public class LogisticsServiceImpl implements LogisticsService {

    @Resource
    private LogisticsMapper logisticsMapper;

    @Resource
    private AuthMapper authMapper;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    @Override
    public ResponseJson sendCertificate(Integer authId, Integer companyId, String logisticsNumber, JSONArray imageList, String remarks, String mobile) {
        List<LogisticsCompanyVo> logisticsCompanyList = logisticsMapper.getLogisticsCompanyList(companyId);
        if (null == logisticsCompanyList || logisticsCompanyList.size() == 0) {
            return ResponseJson.error("物流公司不存在");
        }
        LogisticsCompanyVo logisticsCompany = logisticsCompanyList.get(0);
        CertificateLogisticsPo logistics = new CertificateLogisticsPo();
        logistics.setAuthId(authId);
        logistics.setCompanyName(logisticsCompany.getCompanyName());
        logistics.setCompanyCode(logisticsCompany.getCompanyCode());
        logistics.setLogisticsNumber(logisticsNumber);
        logistics.setRemarks(remarks);
        String imageRemarks = "";
        if (null != imageList){
            String[] imagePath = new String[imageList.size()];
            for (int i = 0; i < imagePath.length; i++) {
                imagePath[i] = imageList.get(i).toString();
            }
            imageRemarks = StringUtils.join(imagePath, "##");
        }
        logistics.setRemarksImage(imageRemarks);
        logistics.setType(4);
        logistics.setState(1);
        logistics.setUpdateDate(new Date());
        logistics.setMobile(mobile);
        logisticsMapper.sendCertificate(logistics);
        // 更改机构寄送状态
        authMapper.updateSendStatus(authId);
        return ResponseJson.success("寄送成功");
    }

    @Override
    public ResponseJson certificateLogistics(Integer authId) {
        CertificateLogisticsVo certificateLogistics = logisticsMapper.getCertificateLogistics(authId);
        if (null != certificateLogistics) {
            String remarksImage = certificateLogistics.getRemarksImage();
            if (StringUtils.isNotEmpty(remarksImage)) {
                String[] imageArr = remarksImage.split("##");
                List<String> imageList = Arrays.asList(imageArr);
                certificateLogistics.setImageList(imageList);
            }
            String info = certificateLogistics.getInfo();
            if (StringUtils.isNotEmpty(info)) {
                List<RouterVo> routers = JSONArray.parseArray(info, RouterVo.class);
                certificateLogistics.setRouterList(routers);
            }
        }
        return ResponseJson.success(certificateLogistics);
    }

    @Override
    public ResponseJson getLogisticsCompany() {
        List<LogisticsCompanyVo> logisticsCompanyList = logisticsMapper.getLogisticsCompanyList(null);
        return ResponseJson.success(logisticsCompanyList);
    }
}
