package com.caimei.service.auth.impl;

import com.caimei.components.RedisService;
import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.cmMapper.ShopMapper;
import com.caimei.mapper.cmMapper.UserMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ShopInfoDto;
import com.caimei.model.po.CmBrandAuthPo;
import com.caimei.model.po.UserPo;
import com.caimei.model.vo.*;
import com.caimei.service.auth.AuthService;
import com.caimei.service.auth.ShopService;
import com.caimei.service.sys.SysUserService;
import com.caimei.utils.*;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Slf4j
@Service
public class ShopServiceImpl implements ShopService {

    @Resource
    private RedisService redisService;

    @Resource
    private AuthService authService;
    @Resource
    private ShopMapper shopMapper;
    @Resource
    private AuthMapper authMapper;
    @Resource
    private UserMapper userMapper;
    @Resource
    private SysUserService sysUserService;


    @Value("${spring.profiles.active}")
    private String active;

    @Override
    public ResponseJson<PageInfo<ShopListVo>> getShopList(Integer listType, String shopName, String loginAccount, Integer shopType, Integer infoId, String mobile, String linkMan, Integer lowerAuditStatus, Integer sendStatus, Integer pageNum, Integer pageSize) {
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<ShopListVo> shopList = shopMapper.getShopList(listType, shopName, loginAccount, shopType, infoId, mobile, linkMan, lowerAuditStatus, sendStatus);
        ListIterator<ShopListVo> iterator = shopList.listIterator();
        while (iterator.hasNext()) {
            // 根据是否完成商品信息审核筛选项，设置下级审核状态
            ShopListVo shop = iterator.next();
            int articleWaitNum = shop.getArticleWaitNum();
            int imageWaitNum = shop.getImageWaitNum();
            int videoWaitNum = shop.getVideoWaitNum();
            int fileWaitNum = shop.getFileWaitNum();
            int zipWaitNum = shop.getZipWaitNum();
            int doctorWaitNum = shop.getDoctorWaitNum();
            int productTypeWaitNum = shop.getProductTypeWaitNum();
            int waitAuditNum = 2 == listType ? shop.getWaitAuditNum() : (3 == listType ? (articleWaitNum + imageWaitNum + videoWaitNum + fileWaitNum + zipWaitNum) : (4 == listType ? doctorWaitNum : (6 == listType ? productTypeWaitNum : 0)));
            if (waitAuditNum > 0) {
                shop.setLowerAuditStatus(0);
            }else {
                shop.setLowerAuditStatus(1);
            }
        }
        PageInfo<ShopListVo> pageData = new PageInfo<>(shopList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson updateShopStatus(Integer authUserId, Integer status) {
        if (authUserId == null) {
            return ResponseJson.error("请输入用户id");
        }
        if (status == null) {
            return ResponseJson.error("请输入要更新的状态值");
        } else if (status != 0 && status != 1) {
            return ResponseJson.error("状态值只能为0或1");
        }
        shopMapper.updateShopStatusByUserId(authUserId, status);
        if (status == 0) {
            return ResponseJson.success("停用供应商成功");
        } else {
            return ResponseJson.success("启用供应商成功");
        }
    }

    @Override
    public ResponseJson resetShopPassword(Integer authUserId) {
        if (authUserId == null) {
            return ResponseJson.error("请输入用户id");
        }
        String newPassword = CodeUtil.generateCode(8);
        String md5Password = Md5Util.md5(newPassword);
        userMapper.updatePasswordByUserId(authUserId, md5Password);
        String mobile = shopMapper.getShopMobileByUserId(authUserId);
        // 发送短信
        String content = "您认证通密码为：" + newPassword + "，请勿泄漏于他人。";
        Boolean sendSms = SmsUtils.sendSms(1, mobile, content);
        if (!sendSms) {
            log.info("供应商重置密码发送失败，手机号:" + mobile);
            return ResponseJson.error("发送失败,请确认手机号无误");
        } else {
            log.info("供应商重置密码发送成功，手机号:" + mobile + ",密码：" + newPassword);
        }
        return ResponseJson.success("密码重置成功");
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseJson saveShop(UserPo shop, List<ShopInfoDto> shopInfoList) {
        // 是否为添加操作
        boolean insertFlag = null == shop.getAuthUserId();
        Integer userIdByMobile = shopMapper.getUserIdByMobile(shop.getMobile());
        Integer userIdByAppId = shopMapper.getUserIdByAppId(shop.getAppId());
        if (insertFlag) {
            // 添加时验证手机号是否已被使用
            if (null != userIdByMobile) {
                return ResponseJson.error("该手机号已被使用，请重新输入", null);
            }
            // 添加时验证供应商名称是否已被使用
            Integer userIdByShopName = shopMapper.getUserIdByShopName(shop.getName());
            if (null != userIdByShopName) {
                return ResponseJson.error("该供应商名称已经存在，请重新输入", null);
            }
            // 添加时验证前缀是否已被使用
            Integer userIdByPrefix = shopMapper.getUserIdByPrefix(shop.getPrefix());
            if (null != userIdByPrefix) {
                return ResponseJson.error("该供应商前缀已经存在，请重新输入", null);
            }
            // 添加时验证appId是否已被使用
            if (StringUtils.isNotEmpty(shop.getAppId()) && null != userIdByAppId) {
                return ResponseJson.error("该appId已被使用，请重新输入", null);
            }
        } else {
            // 修改时验证新手机号是否已被使用
            if (null != userIdByMobile && !userIdByMobile.equals(shop.getAuthUserId())) {
                return ResponseJson.error("该手机号已被使用，请重新输入", null);
            }
            // 修改时验证前缀是否已被使用
            Integer userIdByPrefix = shopMapper.getUserIdByPrefix(shop.getPrefix());
            if (null != userIdByPrefix && !userIdByPrefix.equals(shop.getAuthUserId())) {
                return ResponseJson.error("该供应商前缀已经存在，请重新输入", null);
            }
            // 修改时验证新appId是否已被使用
            if (StringUtils.isNotEmpty(shop.getAppId()) && null != userIdByAppId && !userIdByAppId.equals(shop.getAuthUserId())) {
                return ResponseJson.error("该appId已被使用，请重新输入", null);
            }
        }
        if (insertFlag) {
            // 用户身份：1管理员，2供应商
            shop.setUserIdentity(2);
            // 设置随机8位密码
            String password = CodeUtil.generateCode(8);
            String md5Pwd = Md5Util.md5(password);
            shop.setPassword(md5Pwd);
            // 插入供应商用户
            shopMapper.insertShop(shop);
            // 发送短信
            String content = "您认证通密码为：" + password + "，请勿泄漏于他人。";
            Boolean sendSms = SmsUtils.sendSms(1, shop.getMobile(), content);
            if (!sendSms) {
                log.info("供应商密码发送失败，手机号:" + shop.getMobile());
                return ResponseJson.error("发送失败,请确认手机号无误");
            } else {
                log.info("供应商密码发送成功，手机号:" + shop.getMobile() + ",密码：" + password);
            }
            // 给供应商分配供应商基础角色
            sysUserService.saveRoleRelation(shop.getAuthUserId(), "1");
            log.info("添加供应商，供应商用户id：" + shop.getAuthUserId());
        } else {
            // 更新供应商用户
            shopMapper.updateShopByUserId(shop);
            log.info("更新供应商，供应商用户id:" + shop.getAuthUserId());
        }
        /*
            组装供应商信息数据
         */
        if (insertFlag) {
            shopInfoList.forEach(shopInfo->{
                shopInfo.setAuthUserId(shop.getAuthUserId());
                // 插入供应商信息
                shopMapper.insertShopInfo(shopInfo);
            });
        } else {
            // 数据库中品牌列表数据
            List<ShopInfoVo> dbInfoList = shopMapper.getDbInfoList(shop.getAuthUserId());
            // 原品牌列表编辑后剩余的品牌信息id列表
            List<Integer> newInfoIdList = shopInfoList.stream().filter(shopInfo -> shopInfo.getInfoId() != null).map(ShopInfoDto::getInfoId).collect(Collectors.toList());
            for (ShopInfoVo dbInfo : dbInfoList) {
                if (!newInfoIdList.contains(dbInfo.getInfoId())) {
                    // 判断被删除的品牌下是否还有未删除的商品，若存在，提示供应商需要删除后才能删除品牌
                    Integer productCount = shopMapper.getProductCount(shop.getAuthUserId(), dbInfo.getInfoId());
                    if (null != productCount && productCount > 0) {
                        // 设置手动回滚事务
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        return ResponseJson.error("对不起，该品牌已绑定设备认证，暂时无法删除");
                    } else {
                        // 删除品牌
                        shopMapper.deleteShopInfoById(dbInfo.getInfoId());
                    }
                }
            }
            shopInfoList.forEach(shopInfoVo -> {
                shopInfoVo.setAuthUserId(shop.getAuthUserId());
                // 保存供应商信息数据
                if (shopInfoVo.getInfoId() != null) {
                    // 更新
                    shopMapper.updateShopInfo(shopInfoVo);
                } else {
                    // 插入
                    shopMapper.insertShopInfo(shopInfoVo);
                }
            });
        }
        return ResponseJson.success("保存供应商成功", null);
    }

    @Override
    public ResponseJson<ShopFormVo> getShopFormData(Integer authUserId) {
        if (null == authUserId) {
            return ResponseJson.error("参数异常，请输入供应商用户id", null);
        }
        ShopFormVo shopForm = shopMapper.getShopByUserId(authUserId);
        if (null == shopForm) {
            return ResponseJson.error("供应商不存在", null);
        }
        List<ShopInfoVo> shopInfoList = shopMapper.getShopInfoByUserId(authUserId);
        shopForm.setShopInfo(shopInfoList);
        String existProductInfoIds = "";
        for (ShopInfoVo shopInfo : shopInfoList) {
            if (null != shopInfo.getInfoId()) {
                Integer productCount = shopMapper.getProductCount(authUserId, shopInfo.getInfoId());
                if (null != productCount && productCount > 0) {
                    existProductInfoIds += shopInfo.getInfoId() + ",";
                }
            }
        }
        shopForm.setExistProductInfoIds(existProductInfoIds);
        return ResponseJson.success(shopForm);
    }

    @Override
    public ResponseJson<List<ShopInfoVo>> getShopInfoList(Integer authUserId) {
        List<ShopInfoVo> brandList = shopMapper.getShopInfoList(authUserId);
        return ResponseJson.success(brandList);
    }

    @Override
    public ResponseJson<List<CountryVo>> getCountryList() {
        List<CountryVo> countryList =  shopMapper.getCountryList();
        return ResponseJson.success(countryList);
    }

    @Override
    public ResponseJson<PageInfo<FeedbackVo>> getFeedbackList(Integer authUserId, String authParty, String mobile, Integer handleStatus, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<FeedbackVo> feedbackList = shopMapper.getFeedbackList(authUserId, authParty, mobile, handleStatus);
        PageInfo<FeedbackVo> pageData = new PageInfo<>(feedbackList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<FeedbackVo> getFeedbackFormData(Integer feedbackId) {
        if (null == feedbackId) {
            return ResponseJson.error("参数异常，请输入用户反馈id", null);
        }
        FeedbackVo feedback = shopMapper.getFeedback(feedbackId);
        return ResponseJson.success(feedback);
    }

    @Override
    public ResponseJson handleFeedback(Integer feedbackId, String handleResult) {
        if (null == feedbackId) {
            return ResponseJson.error("参数异常，请输入用户反馈id", null);
        }
        if (StringUtils.isEmpty(handleResult)) {
            return ResponseJson.error("参数异常，请输入用户反馈处理结果", null);
        }
        shopMapper.handleFeedback(feedbackId, handleResult);
        return ResponseJson.success("处理成功");
    }

    @Override
    public List<String> getShopBrands(Integer authUserId) {
        return shopMapper.getShopBrands(authUserId);
    }

    @Override
    public ResponseJson sendVerifyCode(String mobile) {
        if (StringUtils.isEmpty(mobile)) {
            return ResponseJson.error("参数异常,请输入手机号");
        }
        String verifyCode = "prod".equals(active) ? CodeUtil.generateCodeInt(6) : "666666";;
        String content = "您的短信验证码为：" + verifyCode + "，该验证码 5 分钟内有效，请勿泄漏于他人。";
        Boolean sendSms = SmsUtils.sendSms(null, mobile, content);
        if (!sendSms) {
            log.info("短信验证码发送失败，手机号:" + mobile);
            return ResponseJson.error("发送失败,请确认手机号无误");
        } else {
            log.info("短信验证码发送成功，手机号:" + mobile + ",验证码：" + verifyCode);
        }
        redisService.set("code:" + mobile, verifyCode, 300L);
        return ResponseJson.success("发送成功");
    }

    @Override
    public ResponseJson changeMobile(Integer authUserId, String oldMobile, String verifyCode, String newMobile) {
        if (StringUtils.isEmpty(verifyCode)) {
            return ResponseJson.error("参数异常，验证码不能为空");
        }
        if (StringUtils.isEmpty(oldMobile)) {
            return ResponseJson.error("参数异常，旧手机号不能为空");
        }
        if (StringUtils.isEmpty(newMobile)) {
            return ResponseJson.error("参数异常，新手机号不能为空");
        }
        // 校验验证码是否正确
        String redisVerifyCode = null == redisService.get("code:" + oldMobile) ? null : redisService.get("code:" + oldMobile).toString();
        if (!"prod".equals(active)) {
            // 本地和测试环境默认验证码为666666
            redisVerifyCode = "666666";
        }
        if (!verifyCode.equals(redisVerifyCode)) {
            return ResponseJson.error("验证码错误，请重新输入", null);
        }
        Integer userIdByMobile = shopMapper.getUserIdByMobile(newMobile);
        // 验证新手机号是否已被使用
        if (null != userIdByMobile) {
            return ResponseJson.error("该手机号已被使用，请重新输入", null);
        }
        // 更改手机号
        shopMapper.updateShopMobile(authUserId, newMobile);
        return ResponseJson.success("修改成功");
    }

    @Override
    public ResponseJson bindLoginAccount(Integer authUserId, String mobile, String verifyCode, String loginAccount) {
        if (StringUtils.isEmpty(verifyCode)) {
            return ResponseJson.error("参数异常，验证码不能为空");
        }
        if (StringUtils.isEmpty(mobile)) {
            return ResponseJson.error("参数异常，手机号不能为空");
        }
        if (StringUtils.isEmpty(loginAccount)) {
            return ResponseJson.error("参数异常，登录账号不能为空");
        }
        // 校验该账号是否已绑定登录账号
        String dbLoginAccount = shopMapper.getLoginAccount(authUserId);
        if (StringUtils.isNotEmpty(dbLoginAccount)) {
            return ResponseJson.error("您已绑定过登录号码，请勿重复绑定");
        }
        // 校验验证码是否正确
        String redisVerifyCode = null == redisService.get("code:" + mobile) ? null : redisService.get("code:" + mobile).toString();
        if (!"prod".equals(active)) {
            // 本地和测试环境默认验证码为666666
            redisVerifyCode = "666666";
        }
        if (!verifyCode.equals(redisVerifyCode)) {
            return ResponseJson.error("验证码错误，请重新输入", null);
        }
        // 绑定登录账号
        shopMapper.bindLoginAccount(authUserId, loginAccount);
        return ResponseJson.success("绑定成功");
    }

    @Override
    public ResponseJson updateAllAuthImage(Integer authUserId) {
        List<CmBrandAuthPo> authList = authMapper.getAllAuth(authUserId);
        // 获取对应模板
        TemplateVo authTemplate = authMapper.getAuthTemplate(null, authUserId, 1);
        if (null == authTemplate) {
            return ResponseJson.error("请选择使用位置");
        }
        authList.forEach(auth->{
            String authImage;
            if (1 == auth.getAuthImageType()) {
                authImage = authService.generateAuthImage(authTemplate, auth);
                auth.setAuthImage(authImage);
                if (StringUtils.isNotEmpty(authImage)) {
                    auth.setPcAuthImage(authService.addWaterMark(authImage, 1));
                    auth.setAppletsAuthImage(authService.addWaterMark(authImage, 2));
                    authMapper.updateAuthImage(auth);
                }
            }
        });
        return ResponseJson.success();
    }

    @Override
    public ResponseJson changeLinkMan(Integer authUserId, String linkMan) {
        shopMapper.updateShopLinkMan(authUserId, linkMan);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson changeLogo(Integer authUserId, String logo) {
        shopMapper.updateShopLogo(authUserId, logo);
        return ResponseJson.success();
    }

    @Override
    public ResponseJson saveShopInfo(Integer authUserId, ShopInfoDto shopInfo) {
        boolean insertFlag = null == shopInfo.getInfoId();
        if (insertFlag) {
            shopInfo.setAuthUserId(authUserId);
            // 插入供应商信息
            shopMapper.insertShopInfo(shopInfo);
        } else {
            // 更新
            shopMapper.updateShopInfo(shopInfo);
        }
        return ResponseJson.success("保存成功");
    }

    @Override
    public ResponseJson deleteShopInfo(Integer authUserId, Integer infoId) {
        // 判断被删除的品牌下是否还有未删除的商品，若存在，提示供应商需要删除后才能删除品牌
        Integer productCount = shopMapper.getProductCount(authUserId, infoId);
        if (null != productCount && productCount > 0) {
            return ResponseJson.error("对不起，该品牌已绑定设备认证，暂时无法删除");
        } else {
            // 删除品牌
            shopMapper.deleteShopInfoById(infoId);
        }
        return ResponseJson.success("删除成功");
    }

    @Override
    public ResponseJson<List<CmShopVo>> getCmShopList() {
        List<CmShopVo> cmShopList = shopMapper.getCmShopList();
        return ResponseJson.success(cmShopList);
    }

}
