package com.caimei.service.auth.impl;

import com.alibaba.fastjson.JSONArray;
import com.caimei.config.FastDfsClient;
import com.caimei.model.en.QrCodeSize;
import com.caimei.model.po.UploadFilePo;
import com.caimei.service.auth.UploadService;
import com.caimei.utils.FileIOUtils;
import com.caimei.utils.ImageUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.*;
import java.net.URL;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Slf4j
@Service
public class UploadServiceImpl implements UploadService {

    @Autowired
    private FastDfsClient client;

    @Value("${spring.profiles.active}")
    private String active;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    @Override
    public String saveFile(MultipartFile file) throws IOException {
        String originalFilename = file.getOriginalFilename();
        String randomStr = UUID.randomUUID().toString();
        assert originalFilename != null;
        int index = originalFilename.lastIndexOf(".");
        String extName = originalFilename.substring(index);
        String filePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempFile/";
        if ("dev".equals(active)){
            filePath = "D:\\WorkSpace\\file\\tempImport\\";
        }
        filePath += randomStr + extName;
        // 临时图片
        File tempFile = new File(filePath);
        file.transferTo(tempFile);
        log.info("【图片上传】>>>>>>>>>>>>>>>>图片临时路径:" + filePath);
        String imageUrl = imageDomain + "/" + client.uploadFile(filePath);
        // 删除临时图片
        boolean delete = tempFile.delete();
        log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时图片:" + delete);
        return imageUrl;
    }


    @Override
    public String saveImageZip(JSONArray imageArr) throws Exception {
        ArrayList<UploadFilePo> fileList = new ArrayList<>();
        for (Object object : imageArr) {
            UploadFilePo file = new UploadFilePo();
            file.setFileUrl(object.toString());
            String imgRandomId = UUID.randomUUID().toString();
            file.setFileName(imgRandomId);
            fileList.add(file);
        }
        HashMap<String, List<UploadFilePo>> map = new HashMap<>(1);
        map.put("图片压缩包", fileList);
        String imageZipPath = createImageZip(map, 5);
        // 上传zip
        String imageUrl = imageDomain + "/" + client.uploadFile(imageZipPath);
        // 删除临时图片
        File zipFile = new File(imageZipPath);
        boolean delete = zipFile.delete();
        log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时图片压缩包:" + delete);
        return imageUrl;
    }

    /**
     * 创建图片压缩包
     * @param fileMap
     * @param type      1机构授权牌，2设备授权牌，3机构二维码，4设备二维码，5资料库图片压缩包
     * @return
     * @throws Exception
     */
    @Override
    public String createImageZip(Map<String,List<UploadFilePo>> fileMap, Integer type) throws Exception {
        String randomStr = UUID.randomUUID().toString();
        String filePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage/";
        if ("dev".equals(active)){
            filePath = "D:\\uploadZip\\";
        }
        // 压缩文件夹上层临时文件夹路径
        String tempPath = filePath + randomStr;
        // 压缩文件夹路径
        String basePath = "";
        // 生成唯一临时文件夹
        filePath += randomStr + "/";
        // 在临时文件夹中生成要压缩的基础文件夹
        String baseDirName = "";
        switch (type) {
            case 1:
                baseDirName = "机构授权牌";
                break;
            case 2:
                baseDirName = "设备授权牌";
                break;
            case 3:
                baseDirName = "机构二维码";
                break;
            case 4:
                baseDirName = "设备二维码";
                break;
            case 5:
                baseDirName = "图片包";
                break;
            default:
                baseDirName = "";
        }
//        basePath = filePath += baseDirName;
        filePath += baseDirName;
        basePath = filePath;
        File baseDir = new File(basePath);
        if (!baseDir.exists()) {
            baseDir.mkdirs();
        }
        // 往基础文件夹中填充相应数据
        if (1 == type) {
            // 机构授权牌
            List<UploadFilePo> fileList = fileMap.get("机构授权牌");
            for (int i = 0; i < fileList.size(); i++) {
                // 把机构授权牌链接转换为图片
                UploadFilePo file = fileList.get(i);
                String fileUrl = file.getFileUrl();
                URL url = new URL(fileUrl);
                InputStream inputStream = url.openStream();
                BufferedImage authImage = ImageIO.read(inputStream);
                String extName = fileUrl.substring(fileUrl.lastIndexOf(".") + 1);
                String tempFilePath = filePath + "/" + file.getFileName() + "." + extName;
                FileOutputStream outImgStream = new FileOutputStream(tempFilePath);
                ImageIO.write(authImage, extName, outImgStream);
                inputStream.close();
                outImgStream.flush();
                outImgStream.close();
            }
        } else if (2 == type) {
            // 设备授权牌
            for (Map.Entry<String, List<UploadFilePo>> entry : fileMap.entrySet()) {
                String authParty = entry.getKey();
                List<UploadFilePo> fileList = entry.getValue();
                filePath = basePath + "/" + authParty;
                File authDir = new File(filePath);
                if (!authDir.exists()) {
                    authDir.mkdirs();
                }
                for (int i = 0; i < fileList.size(); i++) {
                    // 把设备授权牌链接转换为图片
                    UploadFilePo file = fileList.get(i);
                    String fileUrl = file.getFileUrl();
                    URL url = new URL(fileUrl);
                    InputStream inputStream = url.openStream();
                    BufferedImage authImage = ImageIO.read(inputStream);
                    String extName = fileUrl.substring(fileUrl.lastIndexOf(".") + 1);
                    String tempFilePath = filePath + "/" + file.getFileName() + "." + extName;
                    FileOutputStream outImgStream = new FileOutputStream(tempFilePath);
                    ImageIO.write(authImage, extName, outImgStream);
                    inputStream.close();
                    outImgStream.flush();
                    outImgStream.close();
                }

            }
        } else if (3 == type) {
            // 机构二维码
            List<UploadFilePo> fileList = fileMap.get("机构二维码");
            for (int i = 0; i < fileList.size(); i++) {
                // 把机构二维码链接转换为图片
                UploadFilePo file = fileList.get(i);
                String fileUrl = file.getFileUrl();
                String fileName = file.getFileName();
                BufferedImage qrCodeImage = ImageUtils.createQrCode(fileUrl, QrCodeSize.LARGE);
                String tempFilePath = filePath + "/" + fileName;
                ImageUtils.transferBufferdImage(qrCodeImage, tempFilePath, "png");
            }
        } else if (4 == type) {
            // 设备二维码
            for (Map.Entry<String, List<UploadFilePo>> entry : fileMap.entrySet()) {
                String authParty = entry.getKey();
                List<UploadFilePo> fileList = entry.getValue();
                filePath = basePath + "/" + authParty;
                File authDir = new File(filePath);
                if (!authDir.exists()) {
                    authDir.mkdirs();
                }
                for (int i = 0; i < fileList.size(); i++) {
                    // 把设备授权牌链接转换为图片
                    UploadFilePo file = fileList.get(i);
                    String fileUrl = file.getFileUrl();
                    String fileName = file.getFileName();
                    BufferedImage qrCodeImage = ImageUtils.createQrCode(fileUrl, QrCodeSize.LARGE);
                    String tempFilePath = filePath + "/" + fileName;
                    ImageUtils.transferBufferdImage(qrCodeImage, tempFilePath, "png");
                }
            }
        }
        // 将文件夹转为压缩文件
        String zipPath = tempPath + "/" + baseDirName + ".zip";
        FileOutputStream zipOut = new FileOutputStream(zipPath);
        FileIOUtils.zipFolder(basePath, zipOut, true);
        return zipPath;
    }

    @Override
    public String saveFileByUrl(String url,String fileName) throws Exception {
        InputStream input = new URL(url).openStream();
        File file = inputStreamToFile(input, fileName);
        String filePath = System.getProperty("java.io.tmpdir") + File.separator + fileName;
        log.info("【图片上传】>>>>>>>>>>>>>>>>图片临时路径:" + filePath);
        String imageUrl = imageDomain + "/" + client.uploadFile(filePath);
        // 删除临时图片
        boolean delete = file.delete();
        log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时图片:" + delete);
        return imageUrl;
    }


    /**
     *   工具类
     * inputStream 转 File
     */
    public static File inputStreamToFile(InputStream ins, String name) throws Exception{
//        File file = new File(System.getProperty("java.io.tmpdir") + File.separator + name);
        File file = new File("D:\\uploadZip\\机构二维码\\" + File.separator + name);
        if (file.exists()) {
            return file;
        }
        OutputStream os = new FileOutputStream(file);
        int bytesRead;
        int len = 8192;
        byte[] buffer = new byte[len];
        while ((bytesRead = ins.read(buffer, 0, len)) != -1) {
            os.write(buffer, 0, bytesRead);
        }
        os.close();
        ins.close();
        return file;
    }
}
