package com.caimei.service.data;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.CourseFileListVo;
import com.caimei.model.vo.FileListVo;
import com.caimei.model.vo.WxFileListVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/8
 */
public interface FileService {

    /**
     * 获取文件列表
     *
     * @param listType      列表类型：1文件列表，2文件审核列表
     * @param authUserId    供应商用户id
     * @param fileType
     * @param fileTitle    文件标题
     * @param auditStatus   审核状态
     * @param status        上线状态
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  FileVo
     */
    ResponseJson<PageInfo<FileListVo>> getFileList(Integer listType, Integer authUserId, Integer fileType, String fileTitle, Integer auditStatus, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 添加/编辑文件
     * @param fileId           文件id
     * @param authUserId        供应商用户id
     * @param fileType
     * @param fileTitle        文件标题
     * @param fileName        文件名称
     * @param filePreviewUrl      文件预览链接
     * @param fileDownloadUrl          oss名称
     * @return  ResponseJson
     */
    ResponseJson saveFile(Integer fileId, Integer authUserId, Integer fileType, String fileTitle, String fileName, String filePreviewUrl, String fileDownloadUrl);

    /**
     * 更新文件状态
     * @param fileId       文件id
     * @param status        文件状态:0停用 1启用
     * @return  ResponseJson
     */
    ResponseJson updateFileStatus(Integer fileId, Integer status);

    /**
     * 删除文件
     * @param fileId     文件id
     * @return  ResponseJson
     */
    ResponseJson deleteFile(Integer fileId);

    /**
     * 审核文件
     * @param fileId           文件id
     * @param auditStatus       审核状态：0审核未通过，1审核通过，2待审核
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return
     */
    ResponseJson auditFile(Integer fileId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 微信公众号文件列表
     * @param authUserId        供应商用户id
     * @param fileType
     * @param fileTitle          文件名称
     * @param pageNum           第几页
     * @param pageSize          一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxFileListVo>> getWxFileList(Integer authUserId, Integer fileType, String fileTitle, Integer pageNum, Integer pageSize);

    void download();

    /**
     * 保存教程文件
     * @param fileId        文件id
     * @param fileTitle     文件标题
     * @param fileName      文件名称
     * @param ossName       oss名称
     * @param fileType      文件类型：1视频，2文档
     * @param fileModule    文件模块：1品牌授权-授权列表，2机构管理-机构列表
     * @return
     */
    ResponseJson saveCourseFile(Integer fileId, String fileTitle, String fileName, String ossName, Integer fileType, String fileModule);

    /**
     * 教程文件列表
     * @param fileType      文件类型：1视频，2文档
     * @param fileModule    文件模块：1品牌授权-授权列表，2机构管理-机构列表
     * @param fileTitle     文件标题
     * @param pageNum       页码
     * @param pageSize      每页数量
     * @return
     */
    ResponseJson<PageInfo<CourseFileListVo>> getCourseFileList(Integer fileType, String fileModule, String fileTitle, Integer pageNum, Integer pageSize);

    /**
     * 删除教程文件
     * @param fileId    文件id
     * @return
     */
    ResponseJson deleteCourseFile(Integer fileId);

    /**
     * 更改查看标记
     * @param fileId
     * @return
     */
    ResponseJson checkFile(Integer fileId);
}
