package com.caimei.service.data;

import com.alibaba.fastjson.JSONArray;
import com.caimei.model.ResponseJson;
import com.caimei.model.vo.ImageFormVo;
import com.caimei.model.vo.ImageListVo;
import com.caimei.model.vo.WxImageListVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/8
 */
public interface ImageService {

    /**
     * 获取图片列表
     *
     * @param listType      列表类型：1图片列表，2图片审核列表
     * @param authUserId    供应商用户id
     * @param imageTitle    图片标题
     * @param auditStatus   审核状态
     * @param status        上线状态
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  ImageVo
     */
    ResponseJson<PageInfo<ImageListVo>> getImageList(Integer listType, Integer authUserId, String imageTitle, Integer auditStatus, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 添加/编辑图片
     * @param imageId           图片id
     * @param authUserId        供应商用户id
     * @param imageTitle        图片标题
     * @param imageArr          图片数组
     * @return  ResponseJson
     */
    ResponseJson saveImage(Integer imageId, Integer authUserId, String imageTitle, JSONArray imageArr) throws Exception;

    /**
     * 更新图片状态
     * @param imageId       图片id
     * @param status        图片状态:0停用 1启用
     * @return  ResponseJson
     */
    ResponseJson updateImageStatus(Integer imageId, Integer status);

    /**
     * 删除图片
     * @param imageId     图片id
     * @return  ResponseJson
     */
    ResponseJson deleteImage(Integer imageId);

    /**
     * 审核图片
     * @param imageId           图片id
     * @param auditStatus       审核状态：0审核未通过，1审核通过，2待审核
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return
     */
    ResponseJson auditImage(Integer imageId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 图片回显数据
     * @param imageId   图片id
     * @return
     */
    ResponseJson<ImageFormVo> getImageFormData(Integer imageId);

    /**
     * 微信公众号图片列表
     * @param authUserId    供应商用户id
     * @param imageTitle     图片名称
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxImageListVo>> getWxImageList(Integer authUserId, String imageTitle, Integer pageNum, Integer pageSize);

    /**
     * 更改查看标记
     * @param imageId
     * @return
     */
    ResponseJson checkImage(Integer imageId);
}
