package com.caimei.service.data;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.VideoListVo;
import com.caimei.model.vo.WxVideoListVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/8
 */
public interface VideoService {

    /**
     * 获取视频列表
     *
     * @param listType      列表类型：1视频列表，2视频审核列表
     * @param authUserId    供应商用户id
     * @param videoTitle    视频标题
     * @param auditStatus   审核状态
     * @param status        上线状态
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  VideoVo
     */
    ResponseJson<PageInfo<VideoListVo>> getVideoList(Integer listType, Integer authUserId, String videoTitle, Integer auditStatus, Integer status, Integer pageNum, Integer pageSize);

    /**
     * 添加/编辑视频
     * @param videoId           视频id
     * @param authUserId        供应商用户id
     * @param videoTitle        视频标题
     * @param videoName
     * @param videoPreviewUrl             视频预览链接
     * @param videoDownloadUrl       oss名称
     * @return  ResponseJson
     */
    ResponseJson saveVideo(Integer videoId, Integer authUserId, String videoTitle, String videoImage, String videoName, String videoPreviewUrl, String videoDownloadUrl);

    /**
     * 更新视频状态
     * @param videoId       视频id
     * @param status        视频状态:0停用 1启用
     * @return  ResponseJson
     */
    ResponseJson updateVideoStatus(Integer videoId, Integer status);

    /**
     * 删除视频
     * @param videoId     视频id
     * @return  ResponseJson
     */
    ResponseJson deleteVideo(Integer videoId);

    /**
     * 审核视频
     * @param videoId           视频id
     * @param auditStatus       审核状态：0审核未通过，1审核通过，2待审核
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return
     */
    ResponseJson auditVideo(Integer videoId, Integer auditStatus, String invalidReason, Integer auditBy);

    /**
     * 微信公众号视频列表
     * @param authUserId        供应商用户id
     * @param videoTitle         视频名称
     * @param pageNum           第几页
     * @param pageSize          一页多少条
     * @return
     */
    ResponseJson<PageInfo<WxVideoListVo>> getWxVideoList(Integer authUserId, String videoTitle, Integer pageNum, Integer pageSize);

    /**
     * 更改查看标记
     * @param videoId
     * @return
     */
    ResponseJson checkVideo(Integer videoId);
}
