package com.caimei.service.sys;


import com.caimei.model.ResponseJson;
import com.caimei.model.po.SysMenu;
import com.caimei.model.po.SysMenuTree;
import com.caimei.model.po.SysPermission;
import com.github.pagehelper.PageInfo;

import java.util.List;
import java.util.Set;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/1/6
 */
public interface SysMenuService {
    /**
     * 获取菜单列表
     * @param parentId 父级菜单Id
     * @param menuType 菜单类型：1管理员菜单，2供应商菜单
     * @param status   状态：0启用，1停用
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    ResponseJson<PageInfo<SysMenu>> getMenuList(Integer parentId, Integer menuType, Integer status, int pageNum, int pageSize);
    /**
     * 获取所有启用的菜单列表（树状结构返回）
     */
    ResponseJson<List<SysMenuTree>> getMenuTree(Integer menuType);
    /**
     * 根据ID获取菜单
     */
    ResponseJson<SysMenu> getMenu(Integer id);
    /**
     * 根据ID更新菜单
     */
    ResponseJson<Void> updateMenu(Integer id, SysMenu menu);
    /**
     * 根据ID(可选择的)更新菜单字段
     */
    ResponseJson<Void> updateMenuSelective(Integer id, SysMenu menu);
    /**
     * 添加菜单
     */
    ResponseJson<Void> addMenu(SysMenu menu);
    /**
     * 根据ID删除菜单
     */
    ResponseJson<Void> deleteMenu(Integer id);

    ResponseJson<Void> saveVipMenu(SysMenu menu, List<SysPermission> permissionList);

    /**
     * 获取母菜单及子菜单所有基础菜单
     */
    ResponseJson<Void> getAllBaseMenuIds(SysMenu menu, Set<Integer> menuIdSet, Set<Integer> permissionIdSet);

    ResponseJson<Void> getAllVipMenuIds(SysMenu menu, Set<Integer> menuIdSet, Set<Integer> permissionIdSet);
}
