package com.caimei.service.wechat.impl;

import com.alibaba.fastjson.JSONObject;
import com.caimei.components.RedisService;
import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.cmMapper.ClubMapper;
import com.caimei.mapper.cmMapper.ShopMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ProductSaveDto;
import com.caimei.model.po.ClubUserPo;
import com.caimei.model.po.CmBrandAuthPo;
import com.caimei.model.vo.AuthFormVo;
import com.caimei.model.vo.ShopFormVo;
import com.caimei.model.vo.WxClubUserVo;
import com.caimei.service.auth.AuthProductService;
import com.caimei.service.auth.AuthService;
import com.caimei.service.wechat.RegisterService;
import com.caimei.utils.Md5Util;
import com.caimei.utils.SmsUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/15
 */
@Slf4j
@Service
public class RegisterServiceImpl implements RegisterService {

    @Resource
    private RedisService redisService;
    @Resource
    private ClubMapper clubMapper;
    @Resource
    private AuthMapper authMapper;
    @Resource
    private ShopMapper shopMapper;
    @Resource
    private AuthService authService;
    @Resource
    private AuthProductService authProductService;

    @Override
    public ResponseJson<WxClubUserVo> simpleRegister(String mobile, String verifyCode, String password, Integer authUserId, Integer authId, Integer registerType) {
        // 校验手机号
        WxClubUserVo clubUserVo = clubMapper.getWxClubUser(mobile, null, authUserId, null, null);
        if (null != clubUserVo) {
            return ResponseJson.error(-2, "抱歉，该手机号已注册！", null);
        }
        // 手机号是否有对应的机构
        AuthFormVo auth = null;
        if (null != authId) {
            auth = authMapper.getAuthBaseInfo(null, authId);
            if (1 == auth.getBindStatus()) {
                return ResponseJson.error("该认证信息已被账号注册！", null);
            }
        }/* else {
            auth = authMapper.getAuthBaseInfo(mobile, authUserId, null);
        }*/
        // 校验验证码是否正确
        String redisVerifyCode = null == redisService.get("code:" + mobile) ? null : redisService.get("code:" + mobile).toString();
        if (!verifyCode.equals(redisVerifyCode)) {
            return ResponseJson.error("验证码错误，请重新输入", null);
        }
        if (2 == registerType) {
            // 验证码注册，默认密码
            password = "rzt123456";
        }
        String md5Password = Md5Util.md5(password);
        /*
         * 构建机构用户数据
         */
        ClubUserPo clubUser = new ClubUserPo();
        clubUser.setAuthUserId(authUserId);
        clubUser.setMobile(mobile);
        if (null != auth) {
            clubUser.setAuthId(auth.getAuthId());
            clubUser.setName(auth.getAuthParty());
            // 是否已有其他账号绑定该机构
            /*WxClubUserVo oldUser = clubMapper.getWxClubUser(null, null, null, auth.getAuthId(), null);
            if (null != oldUser) {
                // 解绑
                clubMapper.unbindAuthId(oldUser.getClubUserId());
            }*/
        }
        clubUser.setStatus(1);
        clubUser.setPassword(md5Password);
        clubUser.setAddTime(new Date());
        clubMapper.insertClubUser(clubUser);
        clubUserVo = clubMapper.getWxClubUser(mobile, null, authUserId, null, null);
        if (2 == registerType) {
            // 获取供应商名称
            ShopFormVo shop = shopMapper.getShopByUserId(authUserId);
            String shopName = "";
            if (null == shop) {
                return ResponseJson.error("供应商不存在", null);
            } else {
                shopName = shop.getShopName();
            }
            // 验证码注册，推送默认密码短信
            String content = "（"+ shopName +"）您认证通登录密码为：rzt123456，请勿泄露于他人。【采美网提供技术支持】";
            Boolean sendSms = SmsUtils.sendSms(11, mobile, content);
            if (!sendSms) {
                log.info("机构用户验证码注册-密码发送失败，手机号:" + mobile);
            } else {
                log.info("机构用户验证码注册-密码发送成功，手机号:" + mobile);
            }
        }
        return ResponseJson.success(clubUserVo);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseJson allRegister(Integer authUserId, Integer clubUserId, Integer authId, String registerType, String clubUserInfo, String authInfo, String productInfo) {
        if (registerType.contains("1")) {
            JSONObject clubUserMap = JSONObject.parseObject(clubUserInfo);
            if (null == clubUserMap) {
                return ResponseJson.error("机构用户数据异常");
            }
            String mobile = (String) clubUserMap.get("mobile");
            String verifyCode = (String) clubUserMap.get("verifyCode");
            String password = (String) clubUserMap.get("password");
            ResponseJson<WxClubUserVo> result = simpleRegister(mobile, verifyCode, password, authUserId, authId, 1);
            int code = result.getCode();
            if (0 != code) {
                return result;
            } else {
                WxClubUserVo data = result.getData();
                clubUserId = data.getClubUserId();
            }
        }
        if (registerType.contains("2")) {
            if (StringUtils.isEmpty(authInfo)) {
                // 设置手动回滚事务
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return ResponseJson.error("认证机构数据异常");
            }
            CmBrandAuthPo auth = JSONObject.parseObject(authInfo, CmBrandAuthPo.class);
            auth.setAuthUserId(authUserId);
            JSONObject authMap = JSONObject.parseObject(authInfo);
            String lngAndLat = authMap.getString("lngAndLat");
            if (StringUtils.isEmpty(lngAndLat)) {
                return ResponseJson.error("参数异常，经纬度不能为空", null);
            }
            String[] split = lngAndLat.split(",");
            auth.setLng(new BigDecimal(split[0]));
            auth.setLat(new BigDecimal(split[1]));
            auth.setCustomFlag(0);
            auth.setCreateBy(clubUserId);
            auth.setCreateSource(2);
            List<String> bannerList = (List<String>) authMap.get("bannerList");
            ResponseJson result = authService.saveAuth(auth, bannerList, false, 2);
            int code = result.getCode();
            if (0 != code) {
                // 设置手动回滚事务
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return result;
            } else {
                CmBrandAuthPo data = (CmBrandAuthPo) result.getData();
                authId = data.getId();
            }
        }
        WxClubUserVo clubUser = clubMapper.getWxClubUser(null, null, null, null, clubUserId);
        if (null == clubUser.getAuthId()) {
            // 保存机构用户对应的机构id
            clubMapper.bindAuthId(clubUserId, authId);
        }
        if (registerType.contains("3")) {
            if (StringUtils.isEmpty(productInfo)) {
                // 设置手动回滚事务
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return ResponseJson.error("认证设备数据异常");
            }
            List<ProductSaveDto> productList = JSONObject.parseArray(productInfo, ProductSaveDto.class);
            try{
                for (ProductSaveDto product : productList) {
                    product.setAuthId(authId);
                    product.setSource(2);
                    product.setCreateBy(clubUserId);
                    ResponseJson result = authProductService.saveProduct(product);
                    if (0 != result.getCode()) {
                        // 设置手动回滚事务
                        TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                        return ResponseJson.error(result);
                    }
                }
            }catch (Exception e) {
                // 设置手动回滚事务
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return ResponseJson.error("保存认证设备失败");
            }
        }
        return ResponseJson.success("保存成功");
    }
}
