package com.caimei.task;

import com.caimei.mapper.cmMapper.AuthMapper;
import com.caimei.mapper.ldmMapper.LdmMapper;
import com.caimei.model.po.CmBrandAuthPo;
import com.caimei.model.po.LdmDataPo;
import com.caimei.model.po.TownPo;
import com.caimei.service.auth.UploadService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Arrays;
import java.util.List;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @author Aslee
 */
@Slf4j
@Configuration
@EnableScheduling
@RequiredArgsConstructor
public class LdmTask {
    @Resource
    private AuthMapper authMapper;
    @Resource
    private LdmMapper ldmMapper;

    private UploadService uploadService;

    @Autowired
    public void setUploadService(UploadService uploadService) {
        this.uploadService = uploadService;
    }

    /**
     * 每天凌晨2点读取ldm数据库机构数据，存入采美数据库中
     */
    @Scheduled(cron = "0 0 2 * * ?")
    public void readLdmData() {
        AtomicReference<Integer> ldmLatestClubId = new AtomicReference<>(authMapper.getLdmLatestClubId());
        log.info(">>>>>>>>>>>>>>>>>>>>>>>>>>开始同步，ldmLatestClubId:" + ldmLatestClubId.get());
        List<LdmDataPo> ldmDataList = ldmMapper.getLdmClubData(ldmLatestClubId.get(), null);
        ldmDataList.forEach(ldmData->{
            ldmLatestClubId.set(ldmData.getId());
            String lngAndLat = ldmData.getLngAndLat();
            if (StringUtils.isNotEmpty(lngAndLat)) {
                String[] split = lngAndLat.split(",");
                BigDecimal lat = new BigDecimal(split[0]);
                BigDecimal lng = new BigDecimal(split[1]);
                ldmData.setLng(lng);
                ldmData.setLat(lat);
            }

            String regId1 = ldmData.getRegId1();
            if (StringUtils.isNotEmpty(regId1)) {
                String provinceName = authMapper.getProvinceName(regId1);
                if (StringUtils.isNotEmpty(provinceName) && provinceName.length() > 2) {
                    provinceName = provinceName.substring(0, provinceName.length() - 1).trim();
                }
                Integer provinceId = authMapper.getProvinceId(provinceName);
                ldmData.setProvinceId(provinceId);
            }
            String regId2 = ldmData.getRegId2();
            if (StringUtils.isNotEmpty(regId2)) {
                String cityName = authMapper.getCityName(regId2);
                if (StringUtils.isNotEmpty(cityName) && cityName.length() > 2) {
                    cityName = cityName.substring(0, cityName.length() - 1).trim();
                }
                Integer cityId = authMapper.getCityId(cityName);
                ldmData.setCityId(cityId);
            }
            String regId3 = ldmData.getRegId3();
            if (StringUtils.isNotEmpty(regId3)) {
                String townName = authMapper.getTownName(regId3);
                if (StringUtils.isNotEmpty(townName) && townName.length() > 2) {
                    townName = townName.substring(0, townName.length() - 1).trim();
                    if (townName.startsWith("济源市")) {
                        townName = townName.replace("济源市", "");
                    }
                }
                List<TownPo> townList = authMapper.getTownList(townName);
                townList.forEach(town->{
                    if (null == ldmData.getTownId()) {
                        if (null != ldmData.getCityId()) {
                            if (town.getCityId().equals(ldmData.getCityId())) {
                                ldmData.setTownId(town.getTownId());
                            }
                        } else {
                            Integer cityId = authMapper.getCityIdByTownId(town.getTownId());
                            if (null != ldmData.getProvinceId() && null != cityId) {
                                Integer provinceId = authMapper.getProvinceIdByCityId(cityId);
                                if (ldmData.getProvinceId().equals(provinceId)) {
                                    ldmData.setCityId(cityId);
                                    ldmData.setTownId(town.getTownId());
                                }
                            }
                        }
                    }
                });
            }
            if (null != ldmData.getCityId() && null == ldmData.getTownId()) {
                if (236 == ldmData.getCityId()) {
                    // 三亚市
                    ldmData.setTownId(2198);
                }
            }
            String pic1 = ldmData.getPic1();
            String pic2 = ldmData.getPic2();
            String pic3 = ldmData.getPic3();
            String pic4 = ldmData.getPic4();
            String pic5 = ldmData.getPic5();
            List<String> picList = Arrays.asList(pic1, pic2, pic3, pic4, pic5);
            String logo = null;
            for (String pic : picList) {
                if (null == logo && StringUtils.isNotEmpty(pic)) {
                    try {
                        String imagePath = "https://wangdian.skinovachina.com" + pic;
                        String fileName = imagePath.substring(imagePath.lastIndexOf("/") + 1);
                        logo = uploadService.saveFileByUrl(imagePath, fileName);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
            CmBrandAuthPo authPo = new CmBrandAuthPo();
            BeanUtils.copyProperties(ldmData, authPo);
            authPo.setAuthUserId(10);
            authPo.setCreateBy(10);
            authPo.setLogo(logo);
            authPo.setCustomFlag(0);
            authMapper.insertAuth(authPo);
            // 保存轮播图
            authMapper.insertBanner(authPo.getId(), "https://img.caimei365.com/group1/M00/04/01/rB-lGGJYHJmARujYAAe1RZSC0tg297.png");
        });
        log.info(">>>>>>>>>>>>>>>>>>>>>>>>>>同步结束，ldmLatestClubId:" + ldmLatestClubId.get());
        authMapper.updateLdmLatestClubId(ldmLatestClubId.get());
    }
}
