package com.caimei.utils;

import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.*;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.*;

@Component
public class ExcelOperateUtil {
    private static String active;

    @Value("${spring.profiles.active}")
    public void setActive(String active) {
        ExcelOperateUtil.active = active;
    }

    public static Map<String, XSSFPictureData> getPictures(XSSFSheet sheet) throws IOException {
        Map<String, XSSFPictureData> map = new HashMap<>();
        XSSFDrawing patriarch = sheet.getDrawingPatriarch();
        if (null != patriarch) {
            List<XSSFShape> list = patriarch.getShapes();
            for (XSSFShape shape : list) {
                if (shape instanceof XSSFPicture) {
                    XSSFPicture picture = (XSSFPicture) shape;
                    XSSFClientAnchor cAnchor = (XSSFClientAnchor) picture.getAnchor();
                    XSSFPictureData pdata = picture.getPictureData();
                    String key = cAnchor.getRow1() + "-" + cAnchor.getCol1(); // 行号-列号
                    map.put(key, pdata);
                }
            }
        }
        return map;
    }

    public static Map<String,String> printImg(Map<String, XSSFPictureData> maplist) throws IOException {
        Object[] key = maplist.keySet().toArray();
        String imgSaveDir = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempFile/";
        if ("dev".equals(active)){
            imgSaveDir = "D:\\WorkSpace\\file\\tempImport\\";
        }
        File file = new File(imgSaveDir);
        //目录不存在则创建
        if(!file.exists()) {
            file.mkdirs();
        }
        Map<String,String> temMap = new HashMap<>();
        for (int i = 0; i < maplist.size(); i++) {
            // 获取图片流
            XSSFPictureData pic = maplist.get(key[i]);
            // 获取图片索引
            //String picName = key[i].toString();
            String jpgFileName = "img_" + UUID.randomUUID().toString().replaceAll("-","")+".jpg";
            temMap.put(key[i].toString(), imgSaveDir + jpgFileName);
            byte[] data = pic.getData();
            //图片保存路径
            FileOutputStream out = new FileOutputStream(imgSaveDir+jpgFileName);
            out.write(data);
            out.close();
        }
        return temMap;
    }


    /*public void downloadExcel(String templateFileName, String fileName, HttpServletResponse response) {
        //得到模板文件路径
        String srcFilePath = FileUtils.class.getClassLoader().getResource(templateFileName).getPath();
        InputStream is = null;
        OutputStream out = null;
        //设置响应
        response.setContentType("application/octet-stream; charset=utf-8");
        response.setHeader("Content-Disposition", "attachment; filename=" + Encodes.urlEncode(fileName));
        try {
            is = new BufferedInputStream(new FileInputStream(srcFilePath));
            out = response.getOutputStream();
            int i = 0;
            byte[] buffer = new byte[1024];
            while ((i = is.read(buffer)) != -1) {
                out.write(buffer, 0, i);
                out.flush();
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public void createExcel(String templateFileName, List<?> list, String fileName, HttpServletResponse response) {
        //创建XLSTransformer对象
        XLSTransformer transformer = new XLSTransformer();
        //得到模板文件路径
        String srcFilePath = FileUtils.class.getClassLoader().getResource(templateFileName).getPath();
        Map<String, Object> beanParams = new HashMap<String, Object>();
        beanParams.put("list", list);
        ExcelDateFormatter simpleDateFormat = new ExcelDateFormatter();
        ExcelNumberFormatter excelNumberFormatter = new ExcelNumberFormatter();
        ExcelUserTypeFormatter excelUserTypeFormatter = new ExcelUserTypeFormatter();
        beanParams.put("dateFormat", simpleDateFormat);
        beanParams.put("excelNumberFormatter", excelNumberFormatter);
        beanParams.put("excelUserTypeFormatter", excelUserTypeFormatter);
        InputStream is = null;
        OutputStream out = null;
        //设置响应
        response.setContentType("application/octet-stream; charset=utf-8");
        response.setHeader("Content-Disposition", "attachment; filename=" + Encodes.urlEncode(fileName));
        try {
            is = new BufferedInputStream(new FileInputStream(srcFilePath));
            *//*这里调用了transformer.transformXLS(in, beans)方法得到一个Workbook,这方法会把模板
             *(至于模板怎么写,详细看官方文档)先读入到输入流再处理,再把Workbook的内容写入到输出流发送出去.*//*
            Workbook workbook = transformer.transformXLS(is, beanParams);
            out = response.getOutputStream();
            //将内容写入输出流并把缓存的内容全部发出去  an OLE2 stream, nor an OOXML stream----》模板文件有问题
            workbook.write(out);
            out.flush();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (ParsePropertyException e) {
            e.printStackTrace();
        } catch (InvalidFormatException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                }
            }
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                }
            }
        }
    }*/

    /**
     * @param templateFileName 模板名
     * @param fileName         导出报表的名称
     * @param listSheetNames   形成Excel文件的时候Sheet的Name
     * @param objects          我们传入的对应每个Sheet的一个Java对象
     * @param response
     */
    /*public static void createMultipleSheetsExcel(String templateFileName, String fileName, List<String> listSheetNames, List<List> objects, HttpServletResponse response) {
        //调用引擎生成excel报表
        XLSTransformer transformer = new XLSTransformer();

        //得到模板文件路径
        String srcFilePath = templateFileName;
        InputStream is = null;
        OutputStream out = null;

        //设置响应
        response.setContentType("application/octet-stream; charset=utf-8");
        response.setHeader("Content-Disposition", "attachment; filename=" + Encodes.urlEncode(fileName));

        try {
            is = new BufferedInputStream(new FileInputStream(srcFilePath));
		  *//*
	       * transformMultipleSheetsList(InputStream is, List objects, List newSheetNames, String beanName, Map beanParams, int startSheetNum)
	       *1）is：即Template文件的一个输入流
	        2）objects：即我们传入的对应每个Sheet的一个Java对象，这里传入的List的元素为一个Map对象
	        3）newSheetNames：即形成Excel文件的时候Sheet的Name
	        4）beanName：这个参数在jxls对我们传入的List进行解析的时候使用，而且，该参数还对应Template文件中的Tag，例如，beanName为map，那么在Template文件中取值的公式应该定义成${map.get("property1")}；如果beanName为payslip，公式应该定义成${payslip.get("property1")}
	        5）beanParams：这个参数在使用的时候我的代码没有使用到，这个参数是在如果传入的objects还与其他的对象关联的时候使用的，该参数是一个HashMap类型的参数，如果不使用的话，直接传入new HashMap()即可
	        6）startSheetNo：传入0即可，即SheetNo从0开始
	       *//*
            HashMap hashMap = new HashMap();
            hashMap.put("excelNumberFormatter", new ExcelNumberFormatter());
            Workbook workbook = transformer.transformMultipleSheetsList(is, objects, listSheetNames, "list", hashMap, 0);
            out = response.getOutputStream();
            //将内容写入输出流并把缓存的内容全部发出去
            workbook.write(out);
            out.flush();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                }
            }
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                }
            }
        }
    }*/

    /*public void createExcel(String srcFilePath, Map<String, Object> beanParams, String fileName, HttpServletResponse response) {
        //创建XLSTransformer对象
        XLSTransformer transformer = new XLSTransformer();
        ExcelDateFormatter simpleDateFormat = new ExcelDateFormatter();
        ExcelNumberFormatter excelNumberFormatter = new ExcelNumberFormatter();
        ExcelUserTypeFormatter excelUserTypeFormatter = new ExcelUserTypeFormatter();
        beanParams.put("dateFormat", simpleDateFormat);
        beanParams.put("excelNumberFormatter", excelNumberFormatter);
        beanParams.put("excelUserTypeFormatter", excelUserTypeFormatter);
        InputStream is = null;
        OutputStream out = null;
        //设置响应
        response.setContentType("application/octet-stream; charset=utf-8");
        response.setHeader("Content-Disposition", "attachment; filename=" + Encodes.urlEncode(fileName));
        try {
            is = new BufferedInputStream(new FileInputStream(srcFilePath));
            *//*这里调用了transformer.transformXLS(in, beans)方法得到一个Workbook,这方法会把模板
             *(至于模板怎么写,详细看官方文档)先读入到输入流再处理,再把Workbook的内容写入到输出流发送出去.*//*
            Workbook workbook = transformer.transformXLS(is, beanParams);
            out = response.getOutputStream();
            //将内容写入输出流并把缓存的内容全部发出去  an OLE2 stream, nor an OOXML stream----》模板文件有问题
            workbook.write(out);
            out.flush();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (ParsePropertyException e) {
            e.printStackTrace();
        } catch (InvalidFormatException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                }
            }
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                }
            }
        }
    }*/
}
