package com.caimei.utils;

import lombok.extern.slf4j.Slf4j;

import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

@Slf4j
public class FileZipUtils {

    /**
     * 压缩文件
     *
     * @param f                原文件
     * @param baseDir          打包根目录
     * @param zos              压缩文件
     * @param deleteSourceFile 是否需要删除原文件，例如：true=删除原文件、false=不删除原文件
     */
    public static void compress(File f, String baseDir, ZipOutputStream zos, boolean deleteSourceFile) {
        if (!f.exists()) {
            log.info("待压缩的文件目录或文件" + f.getName() + "不存在");
            return;
        }
        File[] fs = f.listFiles();
        BufferedInputStream bis = null;
        //ZipOutputStream zos = null;
        byte[] bufs = new byte[1024 * 10];
        FileInputStream fis = null;
        try {
            //zos = new ZipOutputStream(new FileOutputStream(zipFile));
            for (int i = 0; i < fs.length; i++) {
                String fName = fs[i].getName();
                log.info("压缩：" + baseDir + fName);
                if (fs[i].isFile()) {
                    ZipEntry zipEntry = new ZipEntry(baseDir + fName);//
                    zos.putNextEntry(zipEntry);
                    //读取待压缩的文件并写进压缩包里
                    fis = new FileInputStream(fs[i]);
                    bis = new BufferedInputStream(fis, 1024 * 10);
                    int read = 0;
                    while ((read = bis.read(bufs, 0, 1024 * 10)) != -1) {
                        zos.write(bufs, 0, read);
                    }
                    //如果需要删除源文件，则需要执行下面2句
                    if (deleteSourceFile) {
                        fis.close();
                        fs[i].delete();
                    }

                } else if (fs[i].isDirectory()) {
                    compress(fs[i], baseDir + fName + "/", zos, false);
                }
            }//end for
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } finally {
            //关闭流
            try {
                if (null != bis) {
                    bis.close();
                }
//                if (null != zos) {
//                    zos.close();
//                }
                if (null != fis) {
                    fis.close();
                }
            } catch (IOException e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
        }

    }

    /**
     * 打包指定路径的文件夹
     *
     * @param sourceFilePath   源文件加地址，例如：C:\\test 必填
     * @param baseDir          打包的根目录名，例如：download/ 非必填
     * @param deleteSourceFile 是否需要删除原文件，例如：true=删除原文件、false=不删除原文件 必填
     */
    public static void compress(String sourceFilePath, String baseDir, boolean deleteSourceFile) {
        File sourceDir = new File(sourceFilePath);
        File zipFile = new File(sourceFilePath + ".zip");
        ZipOutputStream zos = null;
        try {
            zos = new ZipOutputStream(new FileOutputStream(zipFile));
            compress(sourceDir, baseDir, zos, deleteSourceFile);
        } catch (FileNotFoundException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } finally {
            if (zos != null) {
                try {
                    zos.flush();
                    zos.closeEntry();
                    zos.close();
                } catch (IOException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * 递归查询当前目录下所有文件
     *
     * @return
     */
    public static File[] getFileName(String path) {
        File f = new File(path);//获取路径
        long time = f.lastModified();
        Date date = new Date(time);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd E HH:mm");
        String newtime = sdf.format(date);
        log.info("最后一次修改时间-----》" + newtime);
        log.info("文件长度----------------->" + f.length());
        if (!f.exists()) {
            log.info(path + " not exists");//不存在就输出
            return null;
        }
        File fa[] = f.listFiles();//用数组接收  F:笔记总结C#, F:笔记总结if语句.txt
        for (int i = 0; i < fa.length; i++) {//循环遍历
            File fs = fa[i];//获取数组中的第i个
            if (fs.isDirectory()) {
                log.info(fs.getName() + " [目录]");//如果是目录就输出
            } else {
                log.info(fs.getName());//否则直接输出
            }
        }
        return fa;
    }

    /**
     * 文件夹删除
     *
     * @param file
     * @return
     */
    public static Boolean deleteFile(File file) {
        log.info("删除文件---------------》" + file.toString());
        //判断文件不为null或文件目录存在
        if (file == null || !file.exists()) {
            log.info("文件删除失败,请检查文件是否存在以及文件路径是否正确");
            return false;
        }
        //获取目录下子文件
        File[] files = file.listFiles();
        //遍历该目录下的文件对象
        for (File f : files) {
            //判断子目录是否存在子目录,如果是文件则删除
            if (f.isDirectory()) {
                //递归删除目录下的文件
                deleteFile(f);
            } else {
                //文件删除
                f.delete();
                //打印文件名
                log.info("文件名：" + f.getName());
            }
        }
        //文件夹删除
        boolean delete = file.delete();
        System.out.println("目录名：" + file.getName());
        return delete;
    }

}