package com.caimei.utils;

import com.caimei.model.en.QrCodeSize;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.MultiFormatWriter;
import com.google.zxing.common.BitMatrix;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import sun.font.FontDesignMetrics;
import sun.misc.BASE64Encoder;

import javax.imageio.ImageIO;
import javax.swing.*;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/3/16
 */
@Slf4j
@Component
public class ImageUtils {

    private static String active;

    @Value("${spring.profiles.active}")
    public void setActive(String actives) {
        active = actives;
    }

    public static String getImageURL(String dirName, String src, String domain) {
		return getImageURL(dirName, src, 0,domain);
	}

	/***
	 * 获取图片地址
	 *
	 * @param src
	 *            保存在数据库中的图片文件名
	 * @param type
	 *            图片的前缀 (如 type = 200 那么则获取的图片是 200_XXX的图片)
	 * @param dirName
	 *            图片保存的文件夹名 如 (league)
	 * @param domain
	 * 			   加上域名拼成完整路径
	 * @return
	 */
	public static String getImageURL(String dirName, String src, int type, String domain) {


		//正式环境 域名 http --- https处理
		if (domain != null && !"".equals(domain) && domain.startsWith("http:") && domain.toLowerCase().lastIndexOf("config/beta")== -1 && domain.toLowerCase().lastIndexOf("localhost")== -1) {
			domain = domain.replace("http:", "https:");
		}

		//正式环境 图片地址 http --- https处理
		if(src != null && src.startsWith("https:")){
			//非正式环境 使用http
			if (domain !=null && !"".equals(domain) && domain.toLowerCase().lastIndexOf("config/beta")>-1 || domain.toLowerCase().lastIndexOf("localhost")>-1){
				src = src.replace("https:","http:");
			}
			return src;
		}

		//正式环境 图片地址  http --- https处理
		if(src != null && src.startsWith("http:")){
			//非正式环境 使用http
			if (domain !=null && !"".equals(domain) && domain.toLowerCase().lastIndexOf("config/beta")==-1 && domain.toLowerCase().lastIndexOf("localhost")==-1){
				src = src.replace("http:","https:");
			}
			return src;
		}
		type = 0 ;
		dirName = dirName.trim();
		if (dirName == null) {dirName = "";}
		if(src == null || src.equalsIgnoreCase("null")) {src = "";}
		if (src.indexOf(",") > 0) {
			String tmp = src;
			src = tmp.substring(0, tmp.indexOf(","));
		}
		String image = "/img/default/none.jpg";
		if (dirName.equals("user")) {
			image = "/img/default/HeaderImg.png";
		} else if (dirName.equals("club")) {
			image = "/img/default/default_club.jpg";
		} else if (dirName.equals("shopLogo")) {
			image = "/img/default/suppliver.jpg";
		}else if (dirName.equals("caiMeiImage")) {
			image = "/img/default/caiMeiImage.jpg";
		}else {
			image = "/img/default/none.jpg";
		}
		if (src != null && !src.equals("")) {
			if (type != 0 || dirName.equals("product")) {
				src = src.replace("\\", "/");
				String srcActual = src;
				String subDirName = "";
				int index = src.lastIndexOf("/");

				if (index != -1) {
					subDirName = src.substring(0, index + 1);
					srcActual = src.substring(index + 1);
				}
				boolean b = src.startsWith("/uploadFile");
				if(b){
					image = src;
				}else{
					image = "/uploadFile/" + dirName + "/" + subDirName
							+ (type == 0 ? "" : type + "_") + srcActual;
				}
			} else {
				boolean b = src.startsWith("/uploadFile");
				if(b){
					image = src;
				}else{
					image = "/uploadFile/" + dirName + "/" + src;
				}
			}
		}else {
			if(StringUtils.isEmpty(image)) {
				image = "/img/default/none.jpg";
			}
		}
		return domain + image;
	}

	public static String getProductImageURL(String image, int type, String domain) {
		if (image == null) {
			return getImageURL("product", "", type, domain);
		}
		return getImageURL("product", image, type, domain);
	}

	/**
	 * 添加水印图片
	 * @param waterMarkImg	水印图片
	 * @param srcImgURL		原图片路径
	 * @param degree		旋转角度
	 * @return
	 */
	public static String markImageByIcon(Image waterMarkImg, String srcImgURL, Integer degree) {
		//io流
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		try {
			//原图片
			ImageIcon imageIcon = new ImageIcon(new URL(srcImgURL));
			Image srcImg = imageIcon.getImage();
			BufferedImage buffImg = ImageIO.read(new URL(srcImgURL));

			// 1、得到画笔对象
			Graphics2D g = buffImg.createGraphics();

			// 2、设置对线段的锯齿状边缘处理
			g.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
					RenderingHints.VALUE_INTERPOLATION_BILINEAR);

			g.drawImage(
					srcImg.getScaledInstance(srcImg.getWidth(null),
							srcImg.getHeight(null), Image.SCALE_SMOOTH), 0, 0,
					null);
			// 3、设置水印旋转
			if (null != degree) {
				g.rotate(Math.toRadians(degree),
						(double) buffImg.getWidth() / 2,
						(double) buffImg.getHeight() / 2);
			}


			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP,
					1f));

			// 6、水印图片的位置
			int srcWidth = srcImg.getWidth(null);
			int srcHeight = srcImg.getHeight(null);
			int waterMarkWidth = waterMarkImg.getWidth(null);
			int waterMarkHeight = waterMarkImg.getHeight(null);
			g.drawImage(waterMarkImg, (srcWidth - waterMarkWidth) / 2, srcHeight - waterMarkHeight, null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER));
			// 7、释放资源
			g.dispose();

			//将图片写入流中
			ImageIO.write(buffImg, "png", baos);
			//转换成字节
			byte[] bytes = baos.toByteArray();
			BASE64Encoder encoder = new BASE64Encoder();
			//转换成base64串
			String addImage = encoder.encodeBuffer(bytes).trim();
			//删除 \r\n
			addImage = addImage.replaceAll("\n", "").replaceAll("\r", "");
			return "data:image/jpg;base64," + addImage;

		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			try {
				if (null != baos) {
					baos.close();
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		return null;
	}

	public static String addQrCode(String srcImgURL, String qrCodeLink, Integer addTemplateType) {
		//io流
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		try {
			//原图片
			ImageIcon imageIcon = new ImageIcon(new URL(srcImgURL));
			Image srcImg = imageIcon.getImage();
			BufferedImage buffImg = ImageIO.read(new URL(srcImgURL));
			int srcWidth = srcImg.getWidth(null);
			int srcHeight = srcImg.getHeight(null);

			//二维码图片
			int qrCodeSize = getQrCodeSize(srcWidth);
			BufferedImage qrCodeImg = createQrCode(qrCodeLink, qrCodeSize);

			// 1、得到画笔对象
			Graphics2D g = buffImg.createGraphics();

			// 2、设置对线段的锯齿状边缘处理
			g.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
					RenderingHints.VALUE_INTERPOLATION_BILINEAR);

			g.drawImage(
					srcImg.getScaledInstance(srcImg.getWidth(null),
							srcImg.getHeight(null), Image.SCALE_SMOOTH), 0, 0,
					null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP,
					1f));

			// 6、二维码图片的位置
			int qrCodeWidth = qrCodeImg.getWidth(null);
			int qrCodeHeight = qrCodeImg.getHeight(null);
			int x = 0;
			int y = 0;
			if (1 == addTemplateType) {
				x = srcWidth / 4 - qrCodeWidth / 2 - qrCodeWidth/3;
				y = srcHeight* 3 / 4 - qrCodeHeight / 2 - 12;
			} else if (2 == addTemplateType) {
				x = srcWidth * 3 / 4 - qrCodeWidth / 2 + qrCodeWidth;
				y = (srcHeight - qrCodeHeight) / 2;
			} else if (3 == addTemplateType) {
				x = srcWidth / 4 - qrCodeWidth / 2 - qrCodeWidth;
				y = (srcHeight - qrCodeHeight) / 2;
			}
			g.drawImage(qrCodeImg, x, y, null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER));
			// 7、释放资源
			g.dispose();

			//将图片写入流中
			String fileType = srcImgURL.substring(srcImgURL.lastIndexOf(".") + 1);
			ImageIO.write(buffImg, fileType, baos);
			//转换成字节
			byte[] bytes = baos.toByteArray();
			BASE64Encoder encoder = new BASE64Encoder();
			//转换成base64串
			String addImage = encoder.encodeBuffer(bytes).trim();
			//删除 \r\n
			addImage = addImage.replaceAll("\n", "").replaceAll("\r", "");
			return "data:image/jpg;base64," + addImage;

		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			try {
				if (null != baos) {
					baos.close();
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		return null;
	}

	private static int getQrCodeSize(int srcWidth) {
		int qrCodeSize = QrCodeSize.LARGE;
		if (srcWidth < 1350) {
			qrCodeSize = QrCodeSize.MEDIUM;
		}
		if (srcWidth < 1000) {
			qrCodeSize = QrCodeSize.SMALL;
		}
		return qrCodeSize;
	}

	private static final int BLACK = 0xFF000000;
	private static final int WHITE = 0xFFFFFFFF;

	public static BufferedImage createQrCode(String url,int qrCodeSize) {
		try {
			Map<EncodeHintType, String> hints = new HashMap<>();
			hints.put(EncodeHintType.CHARACTER_SET, "UTF-8");
			//设置二维码白边的大小
			hints.put(EncodeHintType.MARGIN, "0");
			BitMatrix bitMatrix = new MultiFormatWriter().encode(url, BarcodeFormat.QR_CODE, qrCodeSize, qrCodeSize, hints);
			int width = bitMatrix.getWidth();
			int height = bitMatrix.getHeight();
			BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
			for (int x = 0; x < width; x++) {
				for (int y = 0; y < height; y++) {
					image.setRGB(x, y, bitMatrix.get(x, y) ? BLACK : WHITE);
				}
			}
			return image;
		} catch (Exception e) {
			e.printStackTrace();
		}
		return null;
	}


	private static String addImage(String srcImgPath, String addImage, Integer x, Integer y) {
		FileOutputStream outImgStream = null;
		String imagePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage";
		if ("dev".equals(active)) {
			imagePath = "D:\\WorkSpace\\file\\tempImage\\";
		}
		try {
			// 读取原图片信息
			File srcImgFile = new File(srcImgPath);
			Image srcImg = ImageIO.read(srcImgFile);
			int srcImgWidth = srcImg.getWidth(null);
			int srcImgHeight = srcImg.getHeight(null);
			BufferedImage buffImg = new BufferedImage(srcImgWidth, srcImgHeight, BufferedImage.TYPE_INT_RGB);


			// 机构名称图片
			URL url = new URL(addImage);
			InputStream inputStream = url.openStream();
			BufferedImage authImage = ImageIO.read(inputStream);

			// 1、得到画笔对象
			Graphics2D g = buffImg.createGraphics();

			// 2、设置对线段的锯齿状边缘处理
			g.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
					RenderingHints.VALUE_INTERPOLATION_BILINEAR);

			g.drawImage(
					srcImg.getScaledInstance(srcImg.getWidth(null),
							srcImg.getHeight(null), Image.SCALE_SMOOTH), 0, 0,
					null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP,
					1f));

			// 6、添加图片的位置
			g.drawImage(authImage, x, y, null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER));
			// 7、释放资源
			g.dispose();

			//将图片写入流中
			String fileType = srcImgPath.substring(srcImgPath.lastIndexOf(".") + 1);


			// 输出图片
			UUID uuid = UUID.randomUUID();
			imagePath += uuid + "." + fileType;
			outImgStream = new FileOutputStream(imagePath);
			ImageIO.write(buffImg, fileType, outImgStream);
			outImgStream.flush();
			outImgStream.close();

		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			try {
				if (null != outImgStream) {
					outImgStream.close();
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		return imagePath;
	}

	private static String addWord(String srcImgPath, String content, String type, String color, int style, int size, int x, int y) {
		FileOutputStream outImgStream = null;
		String imagePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage";
		if ("dev".equals(active)) {
			imagePath = "D:\\WorkSpace\\file\\tempImage\\";
		}
		try {
			// 读取原图片信息
			File srcImgFile = new File(srcImgPath);
			Image srcImg = ImageIO.read(srcImgFile);
			int srcImgWidth = srcImg.getWidth(null);
			int srcImgHeight = srcImg.getHeight(null);
			// 加水印
			BufferedImage buffImg = new BufferedImage(srcImgWidth, srcImgHeight, BufferedImage.TYPE_INT_RGB);
			Graphics2D g = buffImg.createGraphics();
			g.drawImage(srcImg, 0, 0, srcImgWidth, srcImgHeight, null);
			//根据图片的背景设置水印颜色
			String[] split = color.split(",");
			g.setColor(new Color(Integer.parseInt(split[0]), Integer.parseInt(split[1]), Integer.parseInt(split[2])));
			//设置旋转角度
			g.rotate(0, 0, 0);
			//设置水印透明度
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP, 1F));

			// 画认证编号
			Font font = new Font(type, style, size);

			g.setFont(font);
			g.drawString(content, x, y);
			g.dispose();

			String fileType = srcImgPath.substring(srcImgPath.lastIndexOf(".") + 1);

			// 输出图片
			UUID uuid = UUID.randomUUID();
			imagePath += uuid + "." + fileType;
			outImgStream = new FileOutputStream(imagePath);
			ImageIO.write(buffImg, fileType, outImgStream);
			outImgStream.flush();
			outImgStream.close();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			if (outImgStream != null) {
				try {
					outImgStream.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return imagePath;
	}

	private static String addQrCode(String srcImgPath, String qrCodeLink, int qrCodeSize, int x, int y){
		FileOutputStream outImgStream = null;
		String imagePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage";
		if ("dev".equals(active)) {
			imagePath = "D:\\WorkSpace\\file\\tempImage\\";
		}
		try {

			// 读取原图片信息
			File srcImgFile = new File(srcImgPath);
			Image srcImg = ImageIO.read(srcImgFile);
			int srcImgWidth = srcImg.getWidth(null);
			int srcImgHeight = srcImg.getHeight(null);
			// 加水印
			BufferedImage buffImg = new BufferedImage(srcImgWidth, srcImgHeight, BufferedImage.TYPE_INT_RGB);


			//二维码图片
//            int qrCodeSize = getQrCodeSize(srcWidth);
			BufferedImage qrCodeImg = createRealQrCode(qrCodeLink, qrCodeSize);

			// 1、得到画笔对象
			Graphics2D g = buffImg.createGraphics();

			// 2、设置对线段的锯齿状边缘处理
			g.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
					RenderingHints.VALUE_INTERPOLATION_BILINEAR);

			g.drawImage(
					srcImg.getScaledInstance(srcImg.getWidth(null),
							srcImg.getHeight(null), Image.SCALE_SMOOTH), 0, 0,
					null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP,
					1f));

			// 6、二维码图片的位置

			g.drawImage(qrCodeImg, x, y, null);
			g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER));
			// 7、释放资源
			g.dispose();


			String fileType = srcImgPath.substring(srcImgPath.lastIndexOf(".") + 1);

			// 输出图片
			UUID uuid = UUID.randomUUID();
			imagePath += uuid + "." + fileType;
			outImgStream = new FileOutputStream(imagePath);
			ImageIO.write(buffImg, fileType, outImgStream);
			outImgStream.flush();
			outImgStream.close();

		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			try {
				if (null != outImgStream) {
					outImgStream.close();
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		return imagePath;
	}

	public static BufferedImage createRealQrCode(String url,int qrCodeSize) {
		int BLACK = 0xFF000000;
		int WHITE = 0xFFFFFFFF;
		try {
			Map<EncodeHintType, String> hints = new HashMap<>();
			hints.put(EncodeHintType.CHARACTER_SET, "UTF-8");
			//设置二维码白边的大小
			hints.put(EncodeHintType.MARGIN, "0");
			BitMatrix bitMatrix = new MultiFormatWriter().encode(url, BarcodeFormat.QR_CODE, qrCodeSize, qrCodeSize, hints);
			//自定义白边边框宽度
			int margin = 1;
			bitMatrix = updateBit(bitMatrix, margin);
			int width = bitMatrix.getWidth();
			int height = bitMatrix.getHeight();
			BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
			for (int x = 0; x < width; x++) {
				for (int y = 0; y < height; y++) {
					image.setRGB(x, y, bitMatrix.get(x, y) ? BLACK : WHITE);
				}
			}
			//根据size放大、缩小生成的二维码
			image = zoomInImage(image,qrCodeSize,qrCodeSize);
			return image;
		} catch (Exception e) {
			e.printStackTrace();
		}
		return null;
	}

	/**
	 * 图片放大缩小
	 */
	public static BufferedImage  zoomInImage(BufferedImage  originalImage, int width, int height){
		BufferedImage newImage = new BufferedImage(width,height,originalImage.getType());
		Graphics g = newImage.getGraphics();
		g.drawImage(originalImage, 0,0,width,height,null);
		g.dispose();
		return newImage;
	}

	/**
	 * 设置白边
	 * @param matrix
	 * @param margin
	 * @return
	 */
	private static BitMatrix updateBit(BitMatrix matrix, int margin){
		int tempM = margin*2;
		//获取二维码图案的属性
		int[] rec = matrix.getEnclosingRectangle();
		int resWidth = rec[2] + tempM;
		int resHeight = rec[3] + tempM;
		// 按照自定义边框生成新的BitMatrix
		BitMatrix resMatrix = new BitMatrix(resWidth, resHeight);
		resMatrix.clear();
		//循环，将二维码图案绘制到新的bitMatrix中
		for(int i= margin; i < resWidth- margin; i++){
			for(int j=margin; j < resHeight-margin; j++){
				if(matrix.get(i-margin + rec[0], j-margin + rec[1])){
					resMatrix.set(i,j);
				}
			}
		}
		return resMatrix;
	}

	public static String generateAuthImage(Map<String, Object> templateInfo) {
		// 底图
		String templateImage = templateInfo.get("templateImage").toString();
		List<String> tempImageList = new ArrayList<>();
		// 将底图临时存储到本地
		String authImagePath = "";
		String filePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage/";
		if ("dev".equals(active)) {
			filePath = "D:\\WorkSpace\\file\\tempImage\\";
		}
		try {
			URL url = new URL(templateImage);
			InputStream inputStream = url.openStream();
			BufferedImage authImage = ImageIO.read(inputStream);
            String extName = templateImage.substring(templateImage.lastIndexOf(".") + 1);
			UUID uuid = UUID.randomUUID();
            authImagePath = filePath + uuid + "." + extName;
			String tempPath = authImagePath;
			tempImageList.add(tempPath);
			FileOutputStream outImgStream = new FileOutputStream(authImagePath);
            ImageIO.write(authImage, extName, outImgStream);
		} catch (Exception e) {
			e.printStackTrace();
		}
		// 添加图片
		for (int i = 1; i < 5; i++) {
			Object object = templateInfo.get("addImage" + i + "_image");
			if (null != object) {
				String addImage = object.toString();
				int x = Integer.parseInt(templateInfo.get("addImage" + i + "_x").toString());
				int y = Integer.parseInt(templateInfo.get("addImage" + i + "_y").toString());
				authImagePath = addImage(authImagePath, addImage, x, y);
				tempImageList.add(authImagePath);
			}
		}
		// 添加文字
		for (int i = 1; i < 5; i++) {
			Object object = templateInfo.get("addWord" + i + "_content");
			if (null != object) {
				String content = object.toString();
				String type = templateInfo.get("addWord" + i + "_type").toString();
				String color = templateInfo.get("addWord" + i + "_color").toString();
				int style = Integer.parseInt(templateInfo.get("addWord" + i + "_style").toString());
				int size = Integer.parseInt(templateInfo.get("addWord" + i + "_size").toString());
				int x = Integer.parseInt(templateInfo.get("addWord" + i + "_x").toString());
				int y = Integer.parseInt(templateInfo.get("addWord" + i + "_y").toString());
				authImagePath = addWord(authImagePath, content, type, color, style, size, x, y);
				tempImageList.add(authImagePath);
			}
		}
		// 添加二维码
		for (int i = 1; i < 5; i++) {
			Object object = templateInfo.get("addQr" + i + "_link");
			if (null != object) {
				String qrCodeLink = object.toString();
				int qrCodeSize = Integer.parseInt(templateInfo.get("addQr" + i + "_size").toString());
				int x = Integer.parseInt(templateInfo.get("addQr" + i + "_x").toString());
				int y = Integer.parseInt(templateInfo.get("addQr" + i + "_y").toString());
				authImagePath = addQrCode(authImagePath, qrCodeLink, qrCodeSize, x, y);
				tempImageList.add(authImagePath);
			}
		}
		int lastIndex = tempImageList.size() - 1;
		if (lastIndex >= 0) {
			tempImageList.remove(lastIndex);
		}
		tempImageList.forEach(tempImage->{
			// 临时图片
			File tempFile = new File(tempImage);
			// 删除临时图片
			boolean delete = tempFile.delete();
			log.info("【图片上传】>>>>>>>>>>>>>>>>删除临时图片:" + delete);
		});
		return authImagePath;
	}

	public static String transferBufferdImage(BufferedImage qrCodeImage, String filePath, String prefix) {
		filePath = filePath + "." + prefix;
		File file = new File(filePath);
		try {
			ImageIO.write(qrCodeImage, prefix, file);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return filePath;
	}

	/**
	 * 获取水印文字总长度
	 *
	 * @param waterMarkContent 水印的文字
	 * @param g
	 * @return 水印文字总长度
	 */
	public static int getWatermarkLength(String waterMarkContent, Graphics2D g) {
		return g.getFontMetrics(g.getFont()).charsWidth(waterMarkContent.toCharArray(), 0, waterMarkContent.length());
	}

	public static int getWordWidth(Font font, String content) {
		FontDesignMetrics metrics = FontDesignMetrics.getMetrics(font);
		int width = 0;
		for (int i = 0; i < content.length(); i++) {
			width += metrics.charWidth(content.charAt(i));
		}
		return width;
	}
}
