CREATE TABLE `cm_brand_auth_user` (
                                                `authUserId` INT NOT NULL AUTO_INCREMENT,
                                                `name` VARCHAR(100) NULL COMMENT '账号名',
                                                `mobile` VARCHAR(20) NULL COMMENT '手机号',
                                                `password` VARCHAR(100) NULL COMMENT '密码',
                                                `linkMan` VARCHAR(30) NULL COMMENT '联系人',
                                                `userIdentity` INT NULL COMMENT '用户身份：1管理员，2供应商',
                                                `shopType` INT NULL COMMENT '供应商类型：1品牌方，2代理商',
                                                `createTime` DATETIME NULL COMMENT '创建时间',
                                                `createBy` INT NULL COMMENT '创建人Id',
                                                `status` INT NULL COMMENT '状态：0停用，1启用',
                                                PRIMARY KEY (`authUserId`))
    ENGINE = InnoDB
    DEFAULT CHARACTER SET = utf8
    COMMENT = '正品联盟后台管理员';

CREATE TABLE `cm_brand_auth_shop_info` (
                                                   `id` INT NOT NULL AUTO_INCREMENT,
                                                   `authUserId` INT NULL COMMENT '用户Id',
                                                   `brandId` INT NULL COMMENT '所属品牌Id',
                                                   `countryId` INT NULL COMMENT '产地国家id',
                                                   `securityLink` TEXT NULL COMMENT '官网认证链接',
                                                   `statementType` INT NULL COMMENT '代理声明类型：1弹窗，2链接，3图片，4文件',
                                                   `statementContent` TEXT NULL COMMENT '声明弹窗内容',
                                                   `statementLink` VARCHAR(255) NULL COMMENT '声明链接',
                                                   `statementImage` TEXT NULL COMMENT '声明图片',
                                                   PRIMARY KEY (`id`))
    ENGINE = InnoDB
    DEFAULT CHARACTER SET = utf8
    COMMENT = '正品联盟供应商信息';


INSERT INTO `cm_brand_auth_user` (`authUserId`, `name`, `password`, `userIdentity`, `status`) VALUES ('1', 'admin', '2A84213D52B1A2C85FB385A3DEDC789F', '1', '1');


ALTER TABLE `cm_brand_auth`
    ADD COLUMN `authUserId` INT NULL COMMENT '供应商用户id' AFTER `id`,
    ADD COLUMN `status` INT NULL COMMENT '上架状态：0已下架，1已上架' AFTER `authParty`;


ALTER TABLE `cm_brand_auth_product`
    ADD COLUMN `status` INT NULL COMMENT '上架状态：0下架，1上架' AFTER `certificateImage`,
    ADD COLUMN `brandId` INT NULL COMMENT '品牌id' AFTER `authId`,
    ADD COLUMN `pcImage` VARCHAR(255) NULL COMMENT 'pc添加水印商品图片' AFTER `image`,
    ADD COLUMN `appletsImage` VARCHAR(255) NULL COMMENT '小程序添加水印商品图片' AFTER `pcImage`,
    ADD COLUMN `pcCertificateImage` VARCHAR(255) NULL COMMENT 'pc添加水印授权牌照' AFTER `certificateImage`,
    ADD COLUMN `appletsCertificateImage` VARCHAR(255) NULL COMMENT '小程序添加水印授权牌照' AFTER `pcCertificateImage`;


CREATE TABLE `cm_brand_auth_file` (
                                      `id` INT NOT NULL AUTO_INCREMENT,
                                      `authUserId` INT NULL COMMENT '授权用户id',
                                      `brandId` INT NULL COMMENT '品牌id',
                                      `name` VARCHAR(300) NULL COMMENT '文件名称',
                                      `ossName` VARCHAR(300) NULL COMMENT 'oss存储名',
                                      `md5Hex` VARCHAR(32) NULL COMMENT '文件唯一标识',
                                      `uploadTime` DATETIME NULL COMMENT '上传时间',
                                      PRIMARY KEY (`id`))
    ENGINE = InnoDB
    DEFAULT CHARACTER SET = utf8
    COLLATE = utf8_bin
    COMMENT = '品牌授权代理声明文件';


# -----------------------------------------------------------------


UPDATE `cm_brand_auth` set authUserId = 2,status = 1 where id = 1;
UPDATE `cm_brand_auth` set authUserId = 2,status = 1 where id between 3 and 55;
UPDATE `cm_brand_auth` set authUserId = 3,status = 1 where id = 2;

UPDATE `cm_brand_auth_product` set brandId = 144 where id = 1;
UPDATE `cm_brand_auth_product` set brandId = 39 where id = 2;
UPDATE `cm_brand_auth_product` set brandId = 204 where id between 3 and 62;

# ==================================正品联盟6月优化start===============================================
ALTER TABLE `cm_brand_auth`
    DROP COLUMN `statementLink`,
    DROP COLUMN `statementContent`,
    DROP COLUMN `statementType`,
    DROP COLUMN `agentName`,
    DROP COLUMN `agentFlag`,
    DROP COLUMN `securityLink`,
    DROP COLUMN `countryId`,
    DROP COLUMN `brandId`;

ALTER TABLE `cm_brand_auth`
    ADD COLUMN `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核' AFTER `status`,
    ADD COLUMN `invalidReason` VARCHAR(255) NULL COMMENT '审核不通过原因' AFTER `auditStatus`,
    ADD COLUMN `auditBy` INT NULL COMMENT '审核人用户id' AFTER `createBy`,
    ADD COLUMN `auditTime` DATETIME NULL COMMENT '审核时间' AFTER `auditBy`,
    CHANGE COLUMN `status` `status` INT NULL  DEFAULT NULL COMMENT '上架状态：0已下线，1已上线，2待上线' ;

ALTER TABLE `cm_brand_auth_product`
    ADD COLUMN `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核' AFTER `status`,
    ADD COLUMN `invalidReason` VARCHAR(255) NULL COMMENT '审核不通过原因' AFTER `auditStatus`,
    ADD COLUMN `auditBy` INT NULL DEFAULT NULL COMMENT '审核人用户id' AFTER `createBy`,
    ADD COLUMN `auditTime` DATETIME NULL COMMENT '审核时间' AFTER `auditBy`,
    CHANGE COLUMN `status` `status` INT NULL DEFAULT NULL COMMENT '上架状态：0下线，1上线，2待上线' ;

update `cm_brand_auth` set auditStatus = 1, auditBy = 1, auditTime = '2021-06-01 18:17:32';
update `cm_brand_auth_product` set auditStatus = 1, auditBy = 1, auditTime = '2021-06-01 18:17:32';
# ==================================正品联盟6月优化end===============================================
# ==================================正品联盟7月优化end===============================================
CREATE TABLE `cm_brand_club_user` (
                                           `id` INT NOT NULL AUTO_INCREMENT,
                                           `authId` VARCHAR(45) NULL COMMENT '授权机构id',
                                           `invitationCode` VARCHAR(10) NULL COMMENT '邀请码',
                                           `status` INT NULL COMMENT '0未绑定，1已绑定',
                                           `addTime` DATETIME NULL COMMENT '添加时间',
                                           `updateTime` DATETIME NULL COMMENT '更新时间',
                                           `invitationCodeTime` DATETIME NULL COMMENT '邀请码过期时间',
                                           `bindTime` DATETIME NULL COMMENT '绑定时间',
                                           `nickName` VARCHAR(32) NULL COMMENT '微信昵称',
                                           `mobile` VARCHAR(20) NULL COMMENT '手机号',
                                           `openId` VARCHAR(32) NULL COMMENT 'openId',
                                           `delFlag` INT NULL COMMENT '删除（解绑）标识：0未删除，1已删除',
                                           PRIMARY KEY (`id`))
    COMMENT = '授权机构用户表';

CREATE TABLE `cm_brand_article` (
                                         `id` INT NOT NULL AUTO_INCREMENT COMMENT '文章id',
                                         `authUserId` INT NULL COMMENT '供应商用户id',
                                         `title` VARCHAR(50) NULL COMMENT '文章标题',
                                         `image` VARCHAR(255) NULL COMMENT '文章图片',
                                         `content` MEDIUMTEXT NULL COMMENT '文章内容',
                                         `status` INT NULL COMMENT '上线状态：0已下线，1已上线，2待上线',
                                         `createTime` DATETIME NULL COMMENT '创建时间',
                                         `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核',
                                         `invalidReason` VARCHAR(255) NULL COMMENT '审核不通过原因',
                                         `auditBy` INT NULL COMMENT '审核人用户id',
                                         `auditTime` DATETIME NULL COMMENT '审核时间',
                                         PRIMARY KEY (`id`))
    COMMENT = '正品联盟资料库文章';

CREATE TABLE `cm_brand_image` (
                                       `id` INT NOT NULL AUTO_INCREMENT,
                                       `authUserId` INT NULL COMMENT '供应商用户id',
                                       `title` VARCHAR(50) NULL COMMENT '图片标题',
                                       `zipUrl` TEXT NULL COMMENT '图片压缩包链接',
                                       `status` INT NULL COMMENT '上线状态：0已下线，1已上线，2待上线',
                                       `createTime` DATETIME NULL COMMENT '创建时间',
                                       `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核',
                                       `invalidReason` VARCHAR(255) NULL COMMENT '审核不通过原因',
                                       `auditBy` INT NULL COMMENT '审核人用户id',
                                       `auditTime` DATETIME NULL COMMENT '审核时间',
                                       PRIMARY KEY (`id`))
    COMMENT = '正品联盟资料库图片';

CREATE TABLE `cm_brand_image_detail` (
                                          `id` INT NOT NULL AUTO_INCREMENT,
                                          `imageId` INT NULL COMMENT '图片资料id',
                                          `image` VARCHAR(255) NULL COMMENT '图片路径',
                                          PRIMARY KEY (`id`))
    COMMENT = '正品联盟资料库图片详情';

CREATE TABLE `cm_brand_video` (
                                       `id` INT NOT NULL AUTO_INCREMENT,
                                       `authUserId` INT NULL COMMENT '供应商用户id',
                                       `title` VARCHAR(300) NULL COMMENT '视频标题',
                                       `name` VARCHAR(300) NULL COMMENT '视频名称',
                                       `previewUrl` TEXT NULL COMMENT '视频预览链接',
                                       `downloadUrl` TEXT NULL COMMENT '视频下载链接',
                                       `status` INT NULL COMMENT '上线状态：0已下线，1已上线，2待上线',
                                       `createTime` DATETIME NULL COMMENT '创建时间',
                                       `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核',
                                       `invalidReason` VARCHAR(300) NULL COMMENT '审核不通过原因',
                                       `auditBy` INT NULL COMMENT '审核人用户id',
                                       `auditTime` DATETIME NULL COMMENT '审核时间',
                                       PRIMARY KEY (`id`))
    COMMENT = '正品联盟资料库视频';

CREATE TABLE `cm_brand_file` (
                                 `id` INT NOT NULL AUTO_INCREMENT,
                                 `authUserId` INT NULL COMMENT '供应商用户id',
                                 `title` VARCHAR(300) NULL COMMENT '文件标题',
                                 `name` VARCHAR(300) NULL COMMENT '文件名称',
                                 `previewUrl` TEXT NULL COMMENT '文件预览链接',
                                 `downloadUrl` TEXT NULL COMMENT '文件下载链接',
                                 `status` INT NULL COMMENT '上线状态：0已下线，1已上线，2待上线',
                                 `createTime` DATETIME NULL COMMENT '创建时间',
                                 `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核',
                                 `invalidReason` VARCHAR(300) NULL COMMENT '审核不通过原因',
                                 `auditBy` INT NULL COMMENT '审核人用户id',
                                 `auditTime` DATETIME NULL COMMENT '审核时间',
                                 PRIMARY KEY (`id`))
    COMMENT = '正品联盟资料库文件';

CREATE TABLE `cm_brand_club_feedback` (
                                               `id` INT NOT NULL AUTO_INCREMENT,
                                               `clubUserId` INT NULL COMMENT '机构用户id',
                                               `content` VARCHAR(300) NULL COMMENT '反馈内容',
                                               `commitTime` DATETIME NULL COMMENT '提交时间',
                                               `handleStatus` INT NULL COMMENT '处理状态：0未处理，1已处理',
                                               `handleResult` VARCHAR(300) NULL COMMENT '处理结果',
                                               `handleTime` DATETIME NULL COMMENT '处理时间',
                                               PRIMARY KEY (`id`))
    COMMENT = '机构意见反馈表';

ALTER TABLE `cm_brand_auth_user`
    ADD COLUMN `qrCodeImage` TEXT NULL COMMENT '公众号二维码' AFTER `shopType`,
    ADD COLUMN `appId` VARCHAR(45) NULL COMMENT '供应商公众号appId' AFTER `qrCodeImage`,
    ADD COLUMN `appSecret` VARCHAR(45) NULL COMMENT '供应商公众号appSecret' AFTER `appId`;


insert into weixin.menu_tree (`id`,`parentId`,`parentIds`,`name`,`sort`,`wxType`) values (4,0,'0,','上海品辉公众号','10','gh_j3jf92jladsl');
# ==================================正品联盟7月优化end===============================================
# ==================================正品联盟文件上传下载优化start===============================================
ALTER TABLE `cm_brand_file`
    CHANGE COLUMN `downloadUrl` `downloadUrl` VARCHAR(300) NULL DEFAULT NULL COMMENT 'oss名称';

ALTER TABLE `cm_brand_video`
    CHANGE COLUMN `downloadUrl` `downloadUrl` VARCHAR(300) NULL DEFAULT NULL COMMENT 'oss名称';

UPDATE `cm_brand_video` SET `downloadUrl` = '路创丽-preview698384.mp4' WHERE (`id` = '2');
UPDATE `cm_brand_video` SET `downloadUrl` = '9fd29234d5b62c8c9e68b40abef78d5e-preview396856.mp4' WHERE (`id` = '1');
UPDATE `cm_brand_file` SET `downloadUrl` = 'BTL美缇斯-preview856568.pdf' WHERE (`id` = '1');
UPDATE `cm_brand_file` SET `downloadUrl` = '采美365网宣传手册-preview583565.pdf' WHERE (`id` = '2');

# ==================================正品联盟文件上传下载优化end===============================================


